@@ -1,4 +1,4 @@
-<TeXmacs|1.0.6.10>
+<TeXmacs|1.0.7.2>
 
 <style|source>
 
@@ -13,11 +13,10 @@
     <src-copyright|1998--2004|Joris van der Hoeven>
 
     <\src-license>
-      This <TeXmacs> style package falls under the <hlink|GNU general public
-      license|$TEXMACS_PATH/LICENSE> and comes WITHOUT ANY WARRANTY
-      WHATSOEVER. If you do not have a copy of the license, then write to the
-      Free Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-      02111-1307, USA.
+      This software falls under the <hlink|GNU general public license,
+      version 3 or later|$TEXMACS_PATH/LICENSE>. It comes WITHOUT ANY
+      WARRANTY WHATSOEVER. You should have received a copy of the license
+      which the software. If not, see <hlink|http://www.gnu.org/licenses/gpl-3.0.html|http://www.gnu.org/licenses/gpl-3.0.html>.
     </src-license>
   </src-title>>
 
@@ -27,7 +26,13 @@
     </src-comment>
   </active*>
 
-  <assign|session|<macro|body|<style-with|src-compact|none|<compound|<style-with|src-compact|none|<if|<provides|<merge|<value|prog-language>|-session>>|<merge|<value|prog-language>|-session>|generic-session>>|<value|prog-language>|<arg|body>>>>>
+  <assign|session|<\macro|lan|ses|body>
+    <\with|prog-language|<arg|lan>|prog-session|<arg|ses>>
+      <render-session|<arg|body>>
+    </with>
+  </macro>>
+
+  <assign|render-session|<macro|body|<style-with|src-compact|none|<compound|<style-with|src-compact|none|<if|<provides|<merge|<value|prog-language>|-session>>|<merge|<value|prog-language>|-session>|generic-session>>|<value|prog-language>|<arg|body>>>>>
 
   <assign|generic-session|<\macro|name|body>
     <\padded-normal|1fn|1fn>
@@ -43,6 +48,10 @@
 
   <assign|input|<macro|prompt|body|<with|mode|prog|<style-with|src-compact|none|<compound|<style-with|src-compact|none|<if|<provides|<merge|<value|prog-language>|-input>>|<merge|<value|prog-language>|-input>|generic-input>>|<arg|prompt>|<arg|body>>>>>>
 
+  <assign|input-math|<\macro|prompt|in>
+    <input|<arg|prompt>|<math|<arg|in>>>
+  </macro>>
+
   <assign|id-function|<macro|x|<arg|x>>>
 
   <assign|generic-input|<\macro|prompt|body>
@@ -80,6 +89,9 @@
     </wide-normal>
   </macro>>
 
+  <assign|timing|<macro|s|<compound|small|<htab|5mm><with|color|dark
+  grey|<arg|s>>>>>
+
   <\active*>
     <\src-comment>
       Textual fields.
@@ -94,6 +106,38 @@
     </wide-normal>
   </macro>>
 
+  <\active*>
+    <\src-comment>
+      Input-output fields
+    </src-comment>
+  </active*>
+
+  <assign|unfolded-io|<\macro|prompt|in|out>
+    <\surround||<right-flush>>
+      <\input|<with|locus-color|preserve|<action|<arg|prompt>|(mouse-fold)|<arg|in>>>>
+        <arg|in>
+      </input>
+
+      <\output>
+        <arg|out>
+      </output>
+    </surround>
+  </macro>>
+
+  <assign|folded-io|<\macro|prompt|in|out>
+    <\input|<with|locus-color|preserve|<action|<arg|prompt>|(mouse-unfold)|<arg|in>>>>
+      <arg|in>
+    </input>
+  </macro>>
+
+  <assign|unfolded-io-math|<\macro|prompt|in|out>
+    <unfolded-io|<arg|prompt>|<math|<arg|in>>|<arg|out>>
+  </macro>>
+
+  <assign|folded-io-math|<\macro|prompt|in|out>
+    <folded-io|<arg|prompt>|<math|<arg|in>>|<arg|out>>
+  </macro>>
+
   \;
 </body>
 
