@@ -7,10 +7,9 @@
 ;;
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;
-;; This software falls under the GNU general public license and comes WITHOUT
-;; ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for details.
-;; If you don't have this file, write to the Free Software Foundation, Inc.,
-;; 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+;; This software falls under the GNU general public license version 3 or later.
+;; It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+;; in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ;;
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
@@ -30,6 +29,9 @@
   (longrightarrowlim "\\mathop{\\longrightarrow}\\limits")
   (longleftrightarrowlim "\\mathop{\\longleftrightarrow}\\limits")
   (longmapstolim "\\mathop{\\longmapsto}\\limits")
+  (leftsquigarrowlim "\\mathop{\\leftsquigarrow}\\limits")
+  (rightsquigarrowlim "\\mathop{\\rightsquigarrow}\\limits")
+  (leftrightsquigarrowlim "\\mathop{\\leftrightsquigarrow}\\limits")
   (equallim "\\mathop{=}\\limits")
   (longequallim "\\mathop{\\longequal}\\limits")
   (Leftarrowlim "\\mathop{\\leftarrow}\\limits")
@@ -41,10 +43,10 @@
    
   ;; asymptotic relations by Joris
   (nasymp "\\not\\asymp")
-  (asympasymp "\\asymp\\!\\!\\!-")
-  (nasympasymp "\\not\\asymp\\!\\!\\!-")
-  (simsim "\\approx\\!\\!\\!-")
-  (nsimsim "\\not\\approx\\!\\!\\!-")
+  (asympasymp "{\\asymp\\!\\!\\!\\!\\!\\!-}")
+  (nasympasymp "{\\not\\asymp\\!\\!\\!\\!\\!\\!-}")
+  (simsim "{\\approx\\!\\!\\!\\!\\!\\!-}")
+  (nsimsim "{\\not\\approx\\!\\!\\!\\!\\!\\!-}")
   (npreccurlyeq "\\not\\preccurlyeq")
   (precprec "\\prec\\!\\!\\!\\prec")
   (precpreceq "\\preceq\\!\\!\\!\\preceq")
@@ -60,8 +62,10 @@
   (gggeq "\\geq\\negmedspace\\negmedspace\\geq\\negmedspace\\negmedspace\\geq")
 
   ;; extra literal symbols
+  (btimes "{\\mbox{\\rotatebox[origin=c]{90}{$\\ltimes$}}}")
   (Backepsilon "{\\mbox{\\rotatebox[origin=c]{180}{E}}}")
   (Mho "{\\mbox{\\rotatebox[origin=c]{180}{$\\Omega$}}}")
+  (mapmulti "{\\mbox{\\rotatebox[origin=c]{180}{$\\multimap$}}}")
   (mathcatalan "C")
   (mathd "\\mathrm{d}")
   (mathe "\\mathrm{e}")
@@ -83,6 +87,7 @@
   (Zeta "\\mathrm{Z}")
 
   ;; other extra symbols
+  (Exists "\\exists")
   (bigintwl "\\int")
   (bigointwl "\\oint")
   (bignone "")
@@ -191,7 +196,8 @@
 
 (drd-table latex-texmacs-3%
   (subsubindex (index (!append 1 "!" 2 "!" 3)))
-  (tmref 1))
+  (tmref 1)
+  (glossaryentry (!append (item (!option (!append 1 (hfill)))) 2 (dotfill) 3)))
 
 (drd-table latex-texmacs-4%
   (subsubsubindex (index (!append 1 "!" 2 "!" 3 "!" 4))))
@@ -244,7 +250,11 @@
   ("tmindent"
    ((!begin "tmparmod" "1.5em" "0pt" "0pt") ---))
   ("elsequation" ((!begin "eqnarray") (!append --- "&&")))
-  ("elsequation*" ((!begin "eqnarray*") (!append --- "&&"))))
+  ("elsequation*" ((!begin "eqnarray*") (!append --- "&&")))
+  ("theglossary"
+   ((!begin "list" "" (!append "\\setlength{\\labelwidth}{6.5em}"
+			       "\\setlength{\\leftmargin}{7em}"
+			       "\\small")) ---)))
 
 (drd-table latex-texmacs-env-arity%
   ("proof" 0)
@@ -254,17 +264,18 @@
   ("tmindent" 0)
   ("proof" 0)
   ("elsequation" 0)
-  ("elsequation*" 0))
+  ("elsequation*" 0)
+  ("theglossary" 1))
 
 (drd-group latex-texmacs-tag%
   begin-proof begin-proof* begin-tmparmod begin-tmparsep begin-tmindent
-  begin-elsequation begin-elsequation*)
+  begin-elsequation begin-elsequation* begin-theglossary)
 
 (drd-group latex-environment-0%
   begin-proof begin-tmindent begin-elsequation begin-elsequation*)
 
 (drd-group latex-environment-1%
-  begin-proof*)
+  begin-proof* begin-theglossary)
 
 (drd-group latex-environment-3%
   begin-tmparmod begin-tmparsep)
@@ -470,8 +481,14 @@
   ("" "\\^A")
   ("" "{\\aa}")
   ("" "{\\AA}")
+  ("" "\\~A")
+  ("" "\\~a")
+  ("" "{\\AE}")
+  ("" "{\\ae}")
   ("" "\\c{c}")
   ("" "\\c{C}")
+  ("" "{\\dh}")
+  ("" "{\\DH}")
   ("" "\\`e")
   ("" "\\`E")
   ("" "\\'e")
@@ -481,13 +498,15 @@
   ("" "\\^e")
   ("" "\\^E")
   ("" "\\`{\\i}")
-  ("" "\\`{\\I}")
+  ("" "\\`I")
   ("" "\\'{\\i}")
-  ("" "\\'{\\I}")
+  ("" "\\'I")
   ("" "\\\"{\\i}")
-  ("" "\\\"{\\I}")
+  ("" "\\\"I")
   ("" "\\^{\\i}")
-  ("" "\\^{\\I}")
+  ("" "\\^I")
+  ("" "\\~N")
+  ("" "\\~n")
   ("" "\\`o")
   ("" "\\`O")
   ("" "\\'o")
@@ -496,6 +515,13 @@
   ("" "\\\"O")
   ("" "\\^o")
   ("" "\\^O")
+  ("" "\\~O")
+  ("" "\\~o")
+  ("" "{\\O}")
+  ("" "{\\o}")
+  ("" "{\\ss}")
+  ("" "{\\th}")
+  ("" "{\\TH}")
   ("" "\\`u")
   ("" "\\`U")
   ("" "\\'u")
@@ -510,7 +536,7 @@
   ("" "\\\"Y")
   ("" "!`")
   ("" "?`")
-  ("" "{\\ss}"))
+  ("" "?`"))
 
 (drd-table cyrillic-catcodes%
   ("" "\\CYRA")
