@@ -5,10 +5,9 @@
 ;; DESCRIPTION : conversion of TeXmacs trees into TeX/LaTeX trees
 ;; COPYRIGHT   : (C) 2002  Joris van der Hoeven
 ;;
-;; This software falls under the GNU general public license and comes WITHOUT
-;; ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for details.
-;; If you don't have this file, write to the Free Software Foundation, Inc.,
-;; 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+;; This software falls under the GNU general public license version 3 or later.
+;; It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+;; in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ;;
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
@@ -103,7 +102,7 @@
   (block* ("" "c" "" #t))
   (tabular ("" "l" "" #f))
   (tabular* ("" "c" "" #f))
-  (matrix ((#{left\(}#) "c" (#{right\)}#) #f))
+  (matrix ((,(string->symbol "left(")) "c" (,(string->symbol "right)")) #f))
   (det ((left|) "c" (right|) #f))
   (choice ((left\{) "l" (right.) #f)))
 
@@ -270,7 +269,6 @@
 		       ;;(cv (string-convert qs "Cork" "cp936")) ; Chinese?
 		       ;;(cv (string-convert qs "Cork" "cp950")) ; Taiwanese ?
 		       (cv (string-convert qs "Cork" "UTF-8")))
-		  (set! cv (string-append cv ex))
 		  (list '!widechar (string->symbol cv))))))
 	(else (let ((ss (list (string->symbol s))))
 		(cond ((not (drd-in? (car ss) latex-symbol%))
@@ -316,6 +314,7 @@
 	      ((== c #\22) (tmtex-text-sub ",," l))
 	      ((== c #\25) (tmtex-text-sub "--" l))
 	      ((== c #\26) (tmtex-text-sub "---" l))
+	      ((== c #\237) (tmtex-text-sub "\\S" l))
 	      ((== c #\337) (tmtex-text-sub "SS" l))
 	      ((== c #\377) (tmtex-text-sub "" l))
 	      (else (cons c (tmtex-text-list (cdr l))))))))
@@ -595,7 +594,14 @@
 	(else (string-append "\\" s))))
 
 (define (tmtex-left l)
-  (list (string->symbol (string-append "left" (tmtex-large-decode (car l))))))
+  (let* ((s (tmtex-large-decode (car l)))
+	 (n (if (> (length l) 1) (string->number (cadr l)) 0))
+	 (b (cond ((= n 1) "bigl")
+		  ((= n 2) "Bigl")
+		  ((= n 3) "biggl")
+		  ((= n 4) "Biggl")
+		  (else "left"))))
+    (list (string->symbol (string-append b s)))))
 
 (define (tmtex-mid l)
   (let ((s (tmtex-large-decode (car l))))
@@ -604,7 +610,14 @@
 	s)))
 
 (define (tmtex-right l)
-  (list (string->symbol (string-append "right" (tmtex-large-decode (car l))))))
+  (let* ((s (tmtex-large-decode (car l)))
+	 (n (if (> (length l) 1) (string->number (cadr l)) 0))
+	 (b (cond ((= n 1) "bigr")
+		  ((= n 2) "Bigr")
+		  ((= n 3) "biggr")
+		  ((= n 4) "Biggr")
+		  (else "right"))))
+    (list (string->symbol (string-append b s)))))
 
 (define (tmtex-big-decode s)
   (cond ((nstring? s) "bignone")
