@@ -6,10 +6,9 @@
 ;; COPYRIGHT   : (C) 2001  Joris van der Hoeven
 ;;               (C) 2004-2007  Joris van der Hoeven and Henri Lesourd
 ;;
-;; This software falls under the GNU general public license and comes WITHOUT
-;; ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for details.
-;; If you don't have this file, write to the Free Software Foundation, Inc.,
-;; 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+;; This software falls under the GNU general public license version 3 or later.
+;; It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+;; in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ;;
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
@@ -389,9 +388,8 @@
 
 ;; Graphics context [reset]
 (define current-cursor #f)
-(define TM_PATH (var-eval-system "echo $TEXMACS_PATH"))
-(define (tm_xpm name)
-  (string-append TM_PATH "/misc/pixmaps/" name))
+(define TM_PATH (getenv "TEXMACS_PATH"))
+(define (tm_xpm name) (string-append TM_PATH "/misc/pixmaps/" name))
 
 (tm-define (graphics-reset-context cmd)
 ;;FIXME: Should be called only once, when we move out of a <graphics>.
