@@ -7,10 +7,9 @@
 ;; COPYRIGHT   : (C) 2001  Joris van der Hoeven
 ;;               (C) 2004-2007  Joris van der Hoeven and Henri Lesourd
 ;;
-;; This software falls under the GNU general public license and comes WITHOUT
-;; ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for details.
-;; If you don't have this file, write to the Free Software Foundation, Inc.,
-;; 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+;; This software falls under the GNU general public license version 3 or later.
+;; It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+;; in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ;;
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
@@ -386,7 +385,8 @@
 	      )
 	      ((== type 'detailed)
 	       (if nsubd
-		   (set-car! (cdr (list-ref aspect 3)) nsubd)
+		   (set-car! (cdr (list-ref aspect 3))
+			     (number->string nsubd))
 		   (set-car! (cdr (list-ref aspect 3))
 			     (cadr (list-ref
 				     (get-default-val "gr-grid-aspect")
@@ -399,7 +399,7 @@
       )
       (with aspect
 	    `(tuple (tuple "axes" "none") (tuple "1" "none")
-		    (tuple ,nsubd "none"))
+		    (tuple ,(number->string nsubd) "none"))
 	(if (not nsubd)
 	    (set-car! (cdr (list-ref aspect 3))
 		      (cadr (list-ref
@@ -540,9 +540,12 @@
   (with old-mode (graphics-mode)
      (graphics-enter-mode old-mode val)
      (graphics-set-property "gr-mode"
-	(cond ((or (symbol? val) (string? val))
-	       (list 'tuple 'edit val))
+	(cond ((string? val)
+	       (list 'tuple "edit" val))
+	      ((symbol? val)
+	       (list 'tuple "edit" (sy2s val)))
 	      ((pair? val)
+               (set! val (map symbol->string val))
 	       (cons 'tuple val))))))
 
 (tm-define (graphics-group-mode? mode)
@@ -781,7 +784,7 @@
      (if (and (> newud 100) (< newud 10000000))
      (with magn (multiply-magnification
                    (graphics-get-property "magnification") e)
-        (create-graphical-object #f #f #f #f)
+        (graphics-decorations-reset)
         (graphics-set-property "gr-frame" newfr)
         (if magn  
             (graphics-set-property "magnification" magn))))))
@@ -799,7 +802,7 @@
                                  (tuple ,(add x dx)
                                         ,(add y dy))))
      )         
-     (create-graphical-object #f #f #f #f)
+     (graphics-decorations-reset)
      (graphics-set-property "gr-frame" newfr)))
 
 (tm-define (graphics-change-extents dw dh)
@@ -813,7 +816,7 @@
          (set! w w2))
      (if (> (length-decode h2) 0)
          (set! h h2))
-     (create-graphical-object #f #f #f #f)
+     (graphics-decorations-reset)
      (graphics-set-extents w h)))
 
 (tm-define (graphics-change-geo-valign dirn)
