@@ -6,10 +6,9 @@
 ;; COPYRIGHT   : (C) 2001  Joris van der Hoeven
 ;;               (C) 2004-2007  Joris van der Hoeven and Henri Lesourd
 ;;
-;; This software falls under the GNU general public license and comes WITHOUT
-;; ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for details.
-;; If you don't have this file, write to the Free Software Foundation, Inc.,
-;; 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+;; This software falls under the GNU general public license version 3 or later.
+;; It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+;; in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ;;
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
@@ -143,41 +142,42 @@
 )
 (tm-define (get-graphical-prop mode prop)
   (with res
-     (if (== mode 'basic)
+     (cond
+	((== mode 'basic)
 	 (if sticky-point
 	     (get-graphical-prop 'active prop)
 	     (get-graphical-prop current-path prop))
+         )
+	((== mode 'active)
 	 (cond
-	    ((== mode 'active)
-	     (cond
-		((== prop "color")
-		 graphical-color)
-		((== prop "point-style")
-		 graphical-pstyle)
-		((== prop "line-width")
-		 graphical-lwidth)
-		((== prop "magnification")
-		 graphical-magnification)
-		((== prop "dash-style")
-		 graphical-lstyle)
-		((== prop "dash-style-unit")
-		 graphical-lstyle-unit)
-		((== prop "line-arrows")
-		 graphical-larrows)
-		((== prop "fill-color")
-		 graphical-fcolor)
-		((== prop "text-at-halign")
-		 graphical-textat-halign)
-		((== prop "text-at-valign")
-		 graphical-textat-valign)))
-	    ((list? mode)
-	     (if (== prop "magnification")
+	    ((== prop "color")
+	     graphical-color)
+	    ((== prop "point-style")
+	     graphical-pstyle)
+	    ((== prop "line-width")
+	     graphical-lwidth)
+	    ((== prop "magnification")
+	     graphical-magnification)
+	    ((== prop "dash-style")
+	     graphical-lstyle)
+	    ((== prop "dash-style-unit")
+	     graphical-lstyle-unit)
+	    ((== prop "line-arrows")
+	     graphical-larrows)
+	    ((== prop "fill-color")
+	     graphical-fcolor)
+	    ((== prop "text-at-halign")
+	     graphical-textat-halign)
+	    ((== prop "text-at-valign")
+	     graphical-textat-valign)))
+	((list? mode)
+	 (if (== prop "magnification")
 		 (graphics-eval-magnification-at (rcons mode 0))
 		 (graphics-path-property mode prop)))
-	    ((== mode 'new)
-	     (graphics-get-property (string-append "gr-" prop)))
-	    ((== mode 'default)
-	     (get-default-val (string-append "gr-" prop))))
+	((== mode 'new)
+	 (graphics-get-property (string-append "gr-" prop)))
+	(else ;(== mode 'default)
+	 (get-default-val (string-append "gr-" prop)))
      )
      (dv prop res)))
 
@@ -544,7 +544,7 @@
       (begin
 	 (set! edge (car no))
 	 (set! no (cadr no))))
-  (if o
+  (if (and o (not (null? o)))
       (let* ((op (add-selections-colors
 		    (create-graphical-contour o edge no)
 		    default-color-go-points #f))
@@ -719,7 +719,8 @@
      (set! current-path
 	   (if (and (== 1 (length (sketch-get)))
 		    (tree? (car (sketch-get))))
-	       (tree->path (car (sketch-get)))))
+	       (tree->path (car (sketch-get)))
+	       #f))
   )
   (set! sticky-point #f)
   (set! graphics-undo-enabled #t)
