@@ -5,10 +5,9 @@
 ;; DESCRIPTION : keyboard shortcuts for mathematics
 ;; COPYRIGHT   : (C) 1999  Joris van der Hoeven
 ;;
-;; This software falls under the GNU general public license and comes WITHOUT
-;; ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for details.
-;; If you don't have this file, write to the Free Software Foundation, Inc.,
-;; 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+;; This software falls under the GNU general public license version 3 or later.
+;; It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+;; in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ;;
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
@@ -467,6 +466,9 @@
   ("< - - !" "<longleftarrowlim>")
   ("< - - > !" "<longleftrightarrowlim>")
   ("| - - > !" "<longmapstolim>")
+  ("~ > !" "<rightsquigarrowlim>")
+  ("< ~ !" "<leftsquigarrowlim>")
+  ("< ~ > !" "<leftrightsquigarrowlim>")
   ("= !" "<equallim>")
   ("= = !" "<longequallim>")
   ("= > !" "<Rightarrowlim>")
@@ -480,9 +482,11 @@
   ("@ /" "<varnothing>")
   ("@ +" "<oplus>")
   ("@ -" "<ominus>")
+  ("@ - var" "<mapmulti>")
   ("@ x" "<otimes>")
   ("@ :" "<oover>")
-  ("@ ." "<odot>")
+  ("@ *" "<oast>")
+  ("@ x" "<otimes>")
   ("@ R" "<circledR>")
   ("@ S" "<circledS>")
   ("@ / var" "<oslash>")
@@ -993,6 +997,16 @@
   ("math:frak Y" "<frak-Y>")
   ("math:frak Z" "<frak-Z>")
 
+  ("math:bbb 0" "<bbb-0>")
+  ("math:bbb 1" "<bbb-1>")
+  ("math:bbb 2" "<bbb-2>")
+  ("math:bbb 3" "<bbb-3>")
+  ("math:bbb 4" "<bbb-4>")
+  ("math:bbb 5" "<bbb-5>")
+  ("math:bbb 6" "<bbb-6>")
+  ("math:bbb 7" "<bbb-7>")
+  ("math:bbb 8" "<bbb-8>")
+  ("math:bbb 9" "<bbb-9>")
   ("math:bbb a" "<bbb-a>")
   ("math:bbb b" "<bbb-b>")
   ("math:bbb c" "<bbb-c>")
@@ -1140,7 +1154,8 @@
   ("D var var var" "<daleth>")
   ("E var" "<Epsilon>")
   ("E var var" "<exists>")
-  ("E var var var" "<Backepsilon>")
+  ("E var var var" "<Exists>")
+  ("E var var var var" "<Backepsilon>")
   ("F var" "<Phi>")
   ("G var" "<Gamma>")
   ("G var var" "<gimel>")
