@@ -5,14 +5,14 @@
 ;; DESCRIPTION : Initialize pari plugin
 ;; COPYRIGHT   : (C) 1999  Joris van der Hoeven
 ;;
-;; This software falls under the GNU general public license and comes WITHOUT
-;; ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for details.
-;; If you don't have this file, write to the Free Software Foundation, Inc.,
-;; 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+;; This software falls under the GNU general public license version 3 or later.
+;; It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+;; in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ;;
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
 (lazy-menu (pari-menus) pari-menu)
+(define (cas-supports-completions-set! must-be-pari) (noop)) ;; obsolete
 
 (define (pari-initialize)
   (import-from (utils plugins plugin-convert))
@@ -22,19 +22,17 @@
 	(=> "Pari"
 	    (link pari-menu)))))
 
-(define (cas-supports-completions-set! must-be-pari)
-  ;; Hack for old versions of Pari
-  (define (pari-commander s)
-    (string-append (char->string #\002)
-		   "special:" s
-		   (char->string #\005) "\n"))
-  (plugin-configure pari
-    (:tab-completion #t)
-    (:commander ,pari-commander)))
+(define (pari-commander s)
+  (string-append (char->string #\002)
+		 "special:" s
+		 (char->string #\005) "\n"))
 
 (plugin-configure pari
   (:require (url-exists-in-path? "gp"))
   (:initialize (pari-initialize))
   (:launch "gp --texmacs")
   (:session "Pari")
-  (:scripts "Pari"))
+  (:scripts "Pari")
+  (:tab-completion #t)
+  (:commander ,pari-commander))
+
