@@ -4,10 +4,9 @@
 * DESCRIPTION: conversion of tex strings into texmacs trees
 * COPYRIGHT  : (C) 1999  Joris van der Hoeven
 *******************************************************************************
-* This software falls under the GNU general public license and comes WITHOUT
-* ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for more details.
-* If you don't have this file, write to the Free Software Foundation, Inc.,
-* 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+* This software falls under the GNU general public license version 3 or later.
+* It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+* in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ******************************************************************************/
 
 #include "Tex/convert_tex.hpp"
@@ -212,7 +211,7 @@ latex_symbol_to_tree (string s) {
       if (s == "pink") return tree (SET, COLOR, "pink");
 
       cerr << "The symbol was " << s << "\n";
-      fatal_error ("unexpected situation", "latex_symbol_to_tree");
+      FAILED ("unexpected situation");
     }
     if (latex_type (s) == "operator")
       return s(1,N(s));
@@ -275,7 +274,12 @@ string_arg (tree t) {
     return "_" * string_arg (t[0]);
   else if (is_func (t, RSUP, 1))
     return "^" * string_arg (t[0]);
-  else return "";
+  else if (is_func (t, APPLY, 1) && t[0] == "nbsp")
+    return " ";
+  else {
+    cout << "t= " << t << "\n";
+    return "";
+  }
 }
 
 tree
