@@ -4,10 +4,9 @@
 * DESCRIPTION: conversion of tex/latex strings into logical tex/latex trees
 * COPYRIGHT  : (C) 1999  Joris van der Hoeven
 *******************************************************************************
-* This software falls under the GNU general public license and comes WITHOUT
-* ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for more details.
-* If you don't have this file, write to the Free Software Foundation, Inc.,
-* 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+* This software falls under the GNU general public license version 3 or later.
+* It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+* in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ******************************************************************************/
 
 #include "Tex/convert_tex.hpp"
@@ -115,25 +114,19 @@ latex_parser::parse (string s, int& i, string stop, bool change) {
       }
       break;
     }
-    case '%':
-      if (test (s, i, "%%%%%%%%%% Start TeXmacs macros\n")) {
-	while ((i<n) && (!test (s, i, "%%%%%%%%%% End TeXmacs macros\n")))
-	  i++;
-	i += 30;
-      }
-      else {
-	while ((i<n) && (s[i]!='\n')) i++;
-	if (i<n) i++;
-	int ln=0;
-	while ((i<n) && is_space (s[i]))
-	  if (s[i++]=='\n') ln++;
-	if (ln > 0) {
-	  if ((N(t)>0) && ((t[N(t)-1]==" ") || (t[N(t)-1]=="\n")))
-	    t[N(t)-1]= "\n";
-	  else t << "\n";
-	}
+    case '%': {
+      while ((i<n) && (s[i]!='\n')) i++;
+      if (i<n) i++;
+      int ln=0;
+      while ((i<n) && is_space (s[i]))
+	if (s[i++]=='\n') ln++;
+      if (ln > 0) {
+	if ((N(t)>0) && ((t[N(t)-1]==" ") || (t[N(t)-1]=="\n")))
+	  t[N(t)-1]= "\n";
+	else t << "\n";
       }
       break;
+    }
     case '#':
       i++;
       if (i==n) return t;
@@ -699,6 +692,14 @@ latex_parser::parse (string s) {
   for (i=0; i<n; i++)
     if (s[i]=='\n') {
       while ((i<n) && is_space (s[i])) i++;
+      if (test (s, i, "%%%%%%%%%% Start TeXmacs macros\n")) {
+	a << s (start, i);
+	while ((i<n) && (!test (s, i, "%%%%%%%%%% End TeXmacs macros\n")))
+	  i++;
+	i += 30;
+	start= i;
+	continue;
+      }
       if (test (s, i, "\\begin{document}") ||
 	  test (s, i, "\\begin{abstract}") ||
 	  test (s, i, "\\chapter") ||
