@@ -4,10 +4,9 @@
 * DESCRIPTION: routines for the editor
 * COPYRIGHT  : (C) 1999  Joris van der Hoeven
 *******************************************************************************
-* This software falls under the GNU general public license and comes WITHOUT
-* ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for more details.
-* If you don't have this file, write to the Free Software Foundation, Inc.,
-* 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+* This software falls under the GNU general public license version 3 or later.
+* It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+* in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ******************************************************************************/
 
 #include "edit_main.hpp"
@@ -20,7 +19,6 @@
 #include "typesetter.hpp"
 #include "drd_std.hpp"
 #include "message.hpp"
-#include <dlfcn.h>
 #include <setjmp.h>
 
 /******************************************************************************
@@ -37,13 +35,15 @@ editor_rep::editor_rep (server_rep* sv2, tm_buffer buf2):
   et (the_et), rp (buf2->rp) {}
 
 edit_main_rep::edit_main_rep (server_rep* sv, tm_buffer buf):
-  editor_rep (sv, buf), props (UNKNOWN)
+  editor_rep (sv, buf), props (UNKNOWN), ed_obs (edit_observer (this))
 {
+  attach_observer (subtree (et, rp), ed_obs);
   notify_change (THE_TREE);
   tp= correct_cursor (et, rp * 0);
 }
 
 edit_main_rep::~edit_main_rep () {
+  detach_observer (subtree (et, rp), ed_obs);
 #ifdef EXPERIMENTAL
   mem= memorizer ();
 #endif
@@ -51,7 +51,7 @@ edit_main_rep::~edit_main_rep () {
 
 editor
 new_editor (server_rep* sv, tm_buffer buf) {
-  return new edit_main_rep (sv, buf);
+  return tm_new<edit_main_rep> (sv, buf);
 }
 
 /******************************************************************************
@@ -205,7 +205,7 @@ edit_main_rep::print (url name, bool conform, int first, int last) {
     the_box[0][i]->redraw (ren, path (0), rs);
     if (i<end-1) ren->next_page ();
   }
-  delete ren;
+  tm_delete (ren);
 
   if (pdf) {
     ps2pdf (name, orig);
@@ -236,7 +236,8 @@ edit_main_rep::print_snippet (url name, tree t) {
   bool ps= suffix (name) == "ps" || suffix (name) == "eps";
   typeset_prepare ();
   int dpi= as_int (printing_dpi);
-  if (!ps) t= tree (WITH, MAGNIFICATION, "2", PAGE_WIDTH, "40cm", t);
+  //if (!ps) t= tree (WITH, MAGNIFICATION, "2", PAGE_WIDTH, "40cm", t);
+  if (!ps) t= tree (WITH, MAGNIFICATION, "1.6", PAGE_WIDTH, "40cm", t);
   box b= typeset_as_box (env, t, path ());
   if (b->x4 - b->x3 >= 5*PIXEL && b->y4 - b->y3 >= 5*PIXEL) {
     if (ps) make_eps (name, b, dpi);
