@@ -4,10 +4,9 @@
 * DESCRIPTION: typeset the tree being edited
 * COPYRIGHT  : (C) 1999  Joris van der Hoeven
 *******************************************************************************
-* This software falls under the GNU general public license and comes WITHOUT
-* ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for more details.
-* If you don't have this file, write to the Free Software Foundation, Inc.,
-* 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+* This software falls under the GNU general public license version 3 or later.
+* It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+* in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ******************************************************************************/
 
 #include "edit_typeset.hpp"
@@ -124,9 +123,7 @@ edit_typeset_rep::typeset_style_use_cache (tree style) {
     ok= drd->set_locals (t);
   }
   if (!ok) {
-    if (!is_tuple (style))
-      fatal_error ("tuple expected as style",
-		   "edit_interface_rep::typeset_style_using_cache");
+    if (!is_tuple (style)) FAILED ("tuple expected as style");
     tree t (USE_PACKAGE, A (style));
     env->exec (t);
     env->read_env (H);
