@@ -4,10 +4,9 @@
 * DESCRIPTION: cursor handling
 * COPYRIGHT  : (C) 1999  Joris van der Hoeven
 *******************************************************************************
-* This software falls under the GNU general public license and comes WITHOUT
-* ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for more details.
-* If you don't have this file, write to the Free Software Foundation, Inc.,
-* 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+* This software falls under the GNU general public license version 3 or later.
+* It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+* in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ******************************************************************************/
 
 #include "edit_cursor.hpp"
@@ -44,6 +43,8 @@ edit_cursor_rep::make_cursor_accessible (path p, bool forwards) {
     set_access_mode (DRD_ACCESS_SOURCE);
   while (!is_accessible_cursor (et, p) && !in_source ()) {
     path pp;
+    ASSERT (rp <= p, "path outside document");
+    p= rp * closest_inside (subtree (et, rp), p - rp);
     if (forwards ^ inverse)
       pp= rp * next_valid (subtree (et, rp), p - rp);
     else
@@ -96,8 +97,7 @@ edit_cursor_rep::cursor_move_sub (SI& x0, SI& y0, SI& d0, SI dx, SI dy) {
       for (i=1; i<DELTA; i=i<<1)
 	if (ref_p != tree_path (sp, x0, y0, d0+ dx*i)) break;
       if (i>=DELTA)
-	fatal_error ("inconsistent cursor handling",
-		     "edit_cursor_rep::cursor_move_sub");
+	FAILED ("inconsistent cursor handling");
       for (d=i>>2; d>=1; d=d>>1)
 	if (ref_p != tree_path (sp, x0, y0, d0+ dx*(i-d))) i-=d;
       d0 += dx*i;
