@@ -4,20 +4,20 @@
 * DESCRIPTION: interface between the editor and the window manager
 * COPYRIGHT  : (C) 1999  Joris van der Hoeven
 *******************************************************************************
-* This software falls under the GNU general public license and comes WITHOUT
-* ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for more details.
-* If you don't have this file, write to the Free Software Foundation, Inc.,
-* 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+* This software falls under the GNU general public license version 3 or later.
+* It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+* in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ******************************************************************************/
 
 #include "Interface/edit_interface.hpp"
 #include "file.hpp"
 #include "convert.hpp"
 #include "server.hpp"
-#include "tm_buffer.hpp"
+#include "tm_window.hpp"
 #include "Metafont/tex_files.hpp"
 #include "data_cache.hpp"
 #include "drd_mode.hpp"
+#include "message.hpp"
 #ifdef EXPERIMENTAL
 #include "../../Style/Memorizer/clean_copy.hpp"
 #include "../../Style/Evaluate/evaluate_main.hpp"
@@ -33,7 +33,7 @@ MODE_LANGUAGE (string mode) {
   else if (mode == "prog") return PROG_LANGUAGE;
   else if (mode == "src") return LANGUAGE;
   cerr << "Mode = " << mode << "\n";
-  fatal_error ("invalid mode", "MODE_LANGUAGE", "edit_interface.cpp");
+  FAILED ("invalid mode");
   return LANGUAGE;
 }
 
@@ -47,7 +47,7 @@ edit_interface_rep::edit_interface_rep ():
   do_animate (false), next_animate (last_change-1),
   full_screen (false), got_focus (false),
   sh_s (""), sh_len (0),
-  popup_win (NULL),
+  popup_win (),
   sfactor (sv->get_default_shrinking_factor ()),
   pixel (sfactor*PIXEL), copy_always (),
   last_click (0), last_x (0), last_y (0), dragging (false),
@@ -57,13 +57,14 @@ edit_interface_rep::edit_interface_rep ():
   cur_sb (2), cur_wb (2)
 {
   input_mode= INPUT_NORMAL;
-  dis->get_extents (cur_wx, cur_wy);
+  gui_root_extents (cur_wx, cur_wy);
 }
 
 edit_interface_rep::~edit_interface_rep () {
-  if (attached ()) {
-    win->delete_shadow (shadow);
-    win->delete_shadow (stored);
+  if (is_attached (this)) {
+    renderer ren= get_renderer (this);
+    ren->delete_shadow (shadow);
+    ren->delete_shadow (stored);
   }
 }
 
@@ -75,9 +76,10 @@ void
 edit_interface_rep::suspend () {
   got_focus= false;
   notify_change (THE_FOCUS);
-  if (attached ()) {
-    win->delete_shadow (shadow);
-    win->delete_shadow (stored);
+  if (is_attached (this)) {
+    renderer ren= get_renderer (this);
+    ren->delete_shadow (shadow);
+    ren->delete_shadow (stored);
   }
 }
 
@@ -93,16 +95,6 @@ edit_interface_rep::resume () {
   notify_change (THE_FOCUS + THE_EXTENTS + THE_CURSOR);
 }
 
-display
-edit_interface_rep::get_display () {
-  return dis;
-}
-
-widget
-edit_interface_rep::get_widget () {
-  return widget (this);
-}
-
 /******************************************************************************
 * Routines for dealing with shrinked coordinates
 ******************************************************************************/
@@ -124,13 +116,13 @@ edit_interface_rep::set_shrinking_factor (int sf) {
 
 void
 edit_interface_rep::invalidate (SI x1, SI y1, SI x2, SI y2) {
-  this << emit_invalidate ((x1-sfactor+1)/sfactor, (y1-sfactor+1)/sfactor,
-			   (x2+sfactor-1)/sfactor, (y2+sfactor-1)/sfactor);
+  send_invalidate (this, (x1-sfactor+1)/sfactor, (y1-sfactor+1)/sfactor,
+		         (x2+sfactor-1)/sfactor, (y2+sfactor-1)/sfactor);
 }
 
 void
 edit_interface_rep::invalidate (rectangles rs) {
-  while (!nil (rs)) {
+  while (!is_nil (rs)) {
     invalidate (rs->item->x1-pixel, rs->item->y1-pixel,
 		rs->item->x2+pixel, rs->item->y2+pixel);
     rs= rs->next;
@@ -172,7 +164,7 @@ void
 edit_interface_rep::cursor_visible () {
   path sp= find_innermost_scroll (eb, tp);
   cursor cu= get_cursor ();
-  if (nil (sp)) {
+  if (is_nil (sp)) {
     update_visible ();
     cu->y1 -= 2*pixel; cu->y2 += 2*pixel;
     if ((cu->ox+ ((SI) (cu->y1 * cu->slope)) <  vx1) ||
@@ -181,7 +173,7 @@ edit_interface_rep::cursor_visible () {
 	(cu->oy+ cu->y2 >= vy2))
       {
 	scroll_to (cu->ox- ((vx2-vx1)>>1), cu->oy+ ((vy2-vy1)>>1));
-	this << emit_invalidate_all ();
+	send_invalidate_all (this);
       }
   }
   else {
@@ -248,7 +240,7 @@ edit_interface_rep::selection_visible () {
 
   if (scroll_x || scroll_y) {
     scroll_to (new_x, new_y);
-    this << emit_invalidate_all ();
+    send_invalidate_all (this);
     SI old_vx1= vx1, old_vy1= vy1;
     update_visible ();
     end_x += vx1- old_vx1;
@@ -314,6 +306,7 @@ edit_interface_rep::compute_env_rects (path p, rectangles& rs, bool recurse) {
 void
 edit_interface_rep::notify_change (int change) {
   env_change= env_change | change;
+  needs_update ();
 }
 
 bool
@@ -324,8 +317,8 @@ edit_interface_rep::has_changed (int question) {
 int
 edit_interface_rep::idle_time (int event_type) {
   if (env_change == 0 &&
-      win->repainted () &&
-      (!dis->check_event (event_type)) &&
+      get_renderer (this) -> repainted () &&
+      (!check_event (event_type)) &&
       got_focus)
     return texmacs_time () - last_change;
   else return 0;
@@ -351,7 +344,7 @@ edit_interface_rep::apply_changes () {
 	SERVER (menu_icons (1, "(horizontal (link texmacs-context-icons))"));
 	SERVER (menu_icons (2, "(horizontal (link texmacs-extra-icons))"));
 	set_footer ();
-	if (!win->interrupted ()) drd_update ();
+	if (!get_renderer (this) -> interrupted ()) drd_update ();
 	cache_memorize ();
 	last_update= last_change;
       }
@@ -365,9 +358,9 @@ edit_interface_rep::apply_changes () {
 
   // cout << "Handling automatic resizing\n";
   int sb= 1;
-  if (attached () && get_init_string (PAGE_MEDIUM) == "automatic") {
+  if (is_attached (this) && get_init_string (PAGE_MEDIUM) == "automatic") {
     SI wx, wy;
-    win->get_size (wx, wy);
+    ::get_size (get_window (this), wx, wy);
     if (get_init_string (SCROLL_BARS) == "false") sb= 0;
     if (get_server () -> in_full_screen_mode ()) sb= 0;
     if (sb) wx -= 20 * PIXEL;
@@ -380,13 +373,13 @@ edit_interface_rep::apply_changes () {
   }
   if (sb != cur_sb) {
     cur_sb= sb;
-    widget meta= (widget) get_server () -> get_meta ();
-    meta ["canvas"] << set_integer ("scrollbars", sb);
+    tm_window win= get_server () -> get_window ();
+    win -> set_scrollbars (sb);
   }
 
   // window decorations (menu bar, icon bars, footer)
   int wb= 2;
-  if (attached ()) {
+  if (is_attached (this)) {
     string val= get_init_string (WINDOW_BARS);
     if (val == "auto") wb= 2;
     else if (val == "false") wb= 0;
@@ -507,7 +500,7 @@ edit_interface_rep::apply_changes () {
   }
 
   // cout << "Handling backing store\n";
-  if (!nil (stored_rects)) {
+  if (!is_nil (stored_rects)) {
     if (env_change & (THE_TREE+THE_ENVIRONMENT+THE_SELECTION+THE_EXTENTS))
       stored_rects= rectangles ();
   }
@@ -515,14 +508,14 @@ edit_interface_rep::apply_changes () {
     SI gx1, gy1, gx2, gy2;
     if (find_graphical_region (gx1, gy1, gx2, gy2)) {
       rectangle gr= rectangle (gx1, gy1, gx2, gy2);
-      if (!nil (gr - stored_rects))
+      if (!is_nil (gr - stored_rects))
 	invalidate (gx1, gy1, gx2, gy2);
     }
   }
 
   // cout << "Handling environment changes\n";
   if (env_change & THE_ENVIRONMENT)
-    this << emit_invalidate_all ();
+    send_invalidate_all (this);
 
   // cout << "Applied changes\n";
   env_change  = 0;
@@ -574,23 +567,17 @@ edit_interface_rep::after_menu_action () {
 ******************************************************************************/
 
 void
-edit_interface_rep::handle_get_size (get_size_event ev) {
-  dis->get_extents (ev->w, ev->h);
+edit_interface_rep::handle_get_size_hint (SI& w, SI& h) {
+  gui_root_extents (w, h);
 }
 
 void
-edit_interface_rep::handle_attach_window (attach_window_event ev) {
-  basic_widget_rep::handle_attach_window (ev);
-}
-
-void
-edit_interface_rep::handle_resize (resize_event ev) { (void) ev;
+edit_interface_rep::handle_notify_resize (SI w, SI h) {
+  (void) w; (void) h;
   notify_change (THE_TREE);
 }
 
 void
-edit_interface_rep::handle_set_integer (set_integer_event ev) {
-  if (ev->which == "shrinking factor")
-    set_shrinking_factor (ev->i);
-  else a[0]->a[0] << ev;
+edit_interface_rep::handle_set_shrinking_factor (int sf) {
+  set_shrinking_factor (sf);
 }
