@@ -4,10 +4,9 @@
 * DESCRIPTION: Main routines for the modification of the edit tree
 * COPYRIGHT  : (C) 1999  Joris van der Hoeven
 *******************************************************************************
-* This software falls under the GNU general public license and comes WITHOUT
-* ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for more details.
-* If you don't have this file, write to the Free Software Foundation, Inc.,
-* 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+* This software falls under the GNU general public license version 3 or later.
+* It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+* in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ******************************************************************************/
 
 #ifndef EDIT_MODIFY_H
@@ -18,23 +17,12 @@ path inner_paragraph (tree t, path p);
 
 class edit_modify_rep: virtual public editor_rep {
 protected:
-  bool     undo_flag;                // when undoing some text
-  bool     redo_flag;                // when redoing some text
-  observer cur_pos;                  // tree_position corresponding to tp
+  observer cur_pos;  // tree_position corresponding to tp
 
 public:
   edit_modify_rep ();
   ~edit_modify_rep ();
 
-  void assign             (path p, tree u);
-  void insert             (path p, tree u);
-  void remove             (path p, int nr);
-  void split              (path p);
-  void join               (path p);
-  void assign_node        (path p, tree_label op);
-  void insert_node        (path p, tree t);
-  void remove_node        (path p);
-  void finished           (path p);
   void notify_assign      (path p, tree u);
   void notify_insert      (path p, tree u);
   void notify_remove      (path p, int nr);
@@ -45,7 +33,6 @@ public:
   void notify_remove_node (path p);
   void post_notify        (path p);
 
-  void notify_undo (string op, path p, tree t); 
   void mark_undo_blocks ();
   void remove_undo_mark ();
   void add_undo_mark ();
