@@ -4,10 +4,9 @@
 * DESCRIPTION: Selection handling
 * COPYRIGHT  : (C) 1999  Joris van der Hoeven
 *******************************************************************************
-* This software falls under the GNU general public license and comes WITHOUT
-* ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for more details.
-* If you don't have this file, write to the Free Software Foundation, Inc.,
-* 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+* This software falls under the GNU general public license version 3 or later.
+* It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+* in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ******************************************************************************/
 
 #include "Replace/edit_select.hpp"
@@ -99,21 +98,34 @@ edit_select_rep::select_line () {
 
 void
 edit_select_rep::select_from_cursor () {
-  if (!(selecting || shift_selecting)) return;
-  if (path_less (mid_p, tp)) {
-    start_p= copy (mid_p);
-    end_p  = copy (tp);
+  if (selecting) {
+    if (path_less (mid_p, tp)) {
+      start_p= copy (mid_p);
+      end_p  = copy (tp);
+    }
+    else {
+      start_p= copy (tp);
+      end_p  = copy (mid_p);
+    }
+    notify_change (THE_SELECTION);
+    if (shift_selecting) selecting = false;
   }
-  else {
-    start_p= copy (tp);
-    end_p  = copy (mid_p);
-  }
-  notify_change (THE_SELECTION);
 }
 
 void
 edit_select_rep::select_from_cursor_if_active () {
-  if (selecting) select_from_cursor ();
+  if (selecting) {
+    if (path_less (mid_p, tp)) {
+      start_p= copy (mid_p);
+      end_p  = copy (tp);
+    }
+    else {
+      start_p= copy (tp);
+      end_p  = copy (mid_p);
+    }
+    notify_change (THE_SELECTION);
+  }
+  else selection_cancel ();
 }
 
 void
@@ -126,50 +138,74 @@ edit_select_rep::select_from_keyboard (bool flag) {
 
 void
 edit_select_rep::select_from_shift_keyboard () {
-  if ((!shift_selecting) || (end_p == start_p) ||
-      ((tp != start_p) && (tp != end_p)))
-    {
-      selecting= false;
-      shift_selecting= true;
-      mid_p= copy (tp);
-    }
+  if (!shift_selecting || end_p == start_p || (tp != start_p && tp != end_p))
+    mid_p= copy (tp);
+  selecting= true;
+  shift_selecting= true;
 }
 
 /******************************************************************************
 * Enlarging an existing selection
 ******************************************************************************/
 
+static int
+breaking_force (char c) {
+  if (c == ' ') return 3;
+  if (is_punctuation (c)) return 2;
+  if (is_iso_alpha (c) || is_digit (c)) return 0;
+  return 1;
+}
+
+void
+edit_select_rep::select_enlarge_text () {
+  path p= common (start_p, end_p);
+  if (start_p == end_p) p= path_up (p);
+  tree st= subtree (et, p);
+  ASSERT (is_atomic (st), "non textual tree");
+  string s= st->label;
+  string mode= get_env_string (MODE);
+  int i1= last_item (start_p), j1= i1;
+  int i2= last_item (end_p), j2= i2;
+  path q= path_up (p);
+
+  if (mode == "text" || mode == "src") {
+    int i, f= 4;
+    if (i1 > 0) {
+      i= i1; tm_char_backwards (s, i);
+      f= min (f, breaking_force (s[i]));
+    }
+    if (i2 < N(s))
+      f= min (f, breaking_force (s[i2]));
+
+    while (i1 > 0) {
+      i= i1; tm_char_backwards (s, i);
+      if (breaking_force (s[i]) > f) break;
+      i1= i;
+    }
+    while (i2 < N(s)) {
+      if (breaking_force (s[i2]) > f) break;
+      tm_char_forwards (s, i2);
+    }
+
+    if (i1 < i2 && (i1 != j1 || i2 != j2)) {
+      if (is_concat (subtree (et, q)) && i1 == 0 && i2 == N(s))
+	select (q * 0, q * 1);
+      else select (p * i1, p * i2);
+      return;
+    }
+  }
+
+  if (is_concat (subtree (et, q)) || (i1 == 0 && i2 == N(s)))
+    select (q * 0, q * 1);
+  else select (p * 0, p * N(s));
+}
+
 void
 edit_select_rep::select_enlarge () {
   if (start_p == end_p) {
     path p = path_up (start_p);
     tree st= subtree (et, p);
-    if (is_atomic (st)) {
-      string s= st->label;
-      string mode= get_env_string (MODE);
-      if (mode == "text" || mode == "src") {
-	int i1= last_item (start_p), i2= i1;
-	while (i1>0) {
-	  if (s[i1-1] == ' ' || is_punctuation (s[i1-1])) break;
-	  tm_char_backwards (s, i1);
-	}
-	while (i2<N(s)) {
-	  if (s[i2] == ' ' || is_punctuation (s[i2])) break;
-	  tm_char_forwards (s, i2);
-	}
-	if (i1<i2) select (p * i1, p * i2);
-	else {
-	  if (s == "") { p= path_up (p); select (p * 0, p * 1); }
-	  else select (p * 0, p * N(s));
-	}
-      }
-      else {
-	path q= path_up (p);
-	if (is_concat (subtree (et, q)) || (s == ""))
-	  select (q * 0, q * 1);
-	else select (p * 0, p * N(s));
-      }
-    }
+    if (is_atomic (st)) select_enlarge_text ();
     else select (p * 0, p * 1);
   }
   else {
@@ -181,11 +217,7 @@ edit_select_rep::select_enlarge () {
     }
     tree st= subtree (et, p);
     path q = path_up (p);
-    int  i1= last_item (start_p);
-    int  i2= last_item (end_p);
-    if (is_atomic (st) && (!is_concat (subtree (et, q))) &&
-	((i1 != 0) || (i2 != N(st->label))))
-      select (p * 0, p * N(st->label));
+    if (is_atomic (st)) select_enlarge_text ();
     else select (q * 0, q * 1);
   }
 
@@ -280,8 +312,8 @@ static path
 table_search_format (tree t, path p) {
   tree st= subtree (t, p);
   if (is_func (st, TFORMAT) && is_func (st[N(st)-1], TABLE)) return p;
-  while ((!nil (p)) && (!is_func (subtree (t, p), TABLE))) p= path_up (p);
-  if ((!nil (p)) && (is_func (subtree (t, path_up (p)), TFORMAT)))
+  while ((!is_nil (p)) && (!is_func (subtree (t, p), TABLE))) p= path_up (p);
+  if ((!is_nil (p)) && (is_func (subtree (t, path_up (p)), TFORMAT)))
     p= path_up (p);
   return p;
 }
@@ -290,7 +322,7 @@ static void
 table_search_coordinates (tree t, path p, int& row, int& col) {
   row= col= 0;
   while (true) {
-    if (nil (p)) p= path (1);
+    if (is_nil (p)) p= path (1);
     if (p == path (0)) p= path (0, 0);
     if (p == path (1)) p= path (N(t)-1, 1);
     if (is_func (t, TFORMAT));
@@ -334,7 +366,7 @@ selection_correct (tree t, path i1, path i2, path& o1, path& o2) {
     o1= i1;
     o2= i2;
   }
-  else if (atom (i1) || atom (i2)) {
+  else if (is_atom (i1) || is_atom (i2)) {
     if (is_atomic (t)) {
       o1= i1;
       o2= i2;
@@ -376,7 +408,8 @@ static void
 selection_bcorrect (drd_info drd, tree t, path i1, path i2, path& o1, path& o2)
 {
   o1= i1; o2= i2;
-  if (is_compound (t) && !atom (i1) && !atom (i2) && i1->item == i2->item) {
+  if (is_compound (t) && !is_atom (i1) && !is_atom (i2) &&
+      i1->item == i2->item) {
     path O1, O2;
     selection_bcorrect (drd, t[i1->item], i1->next, i2->next, O1, O2);
     if (drd->var_without_border (L(t[i1->item])) && (O1->item != O2->item)) {
@@ -397,21 +430,21 @@ compute_selection (tree t, path start, path end) {
   path p1= start->next;
   path p2= end->next;
 
-  if (nil (p1) || nil (p2)) {
+  if (is_nil (p1) || is_nil (p2)) {
     if (start == path (right_index (t))) return "";
     if (end == path (0)) return "";
     if (start == end) return "";
-    if (nil (p1) && nil (p2)) {
+    if (is_nil (p1) && is_nil (p2)) {
       if (is_compound (t)) return copy (t);
       if (i1>=i2) return "";
       return t->label (i1, i2);
     }
     if (is_compound (t) && (!is_format (t))) return copy (t);
-    if (nil (p1)) {
+    if (is_nil (p1)) {
       i1= 0;
       p1= (start->item==0? 0: right_index (t[i1]));
     }
-    if (nil (p2)) {
+    if (is_nil (p2)) {
       i2= N(t)-1;
       p2= (end->item==0? 0: right_index (t[i2]));
     }
@@ -520,12 +553,14 @@ edit_select_rep::selection_get_path () {
 
 void
 edit_select_rep::selection_raw_set (string key, tree t) {
-  (void) dis->set_selection (widget (this), key, t, "");
+  (void) ::set_selection (key, t, "");
 }
 
 tree
 edit_select_rep::selection_raw_get (string key) {
-  return copy (dis->get_selection (widget (this), key));
+  tree t; string s;
+  (void) ::get_selection (key, t, s);
+  return t;
 }
 
 void
@@ -551,12 +586,11 @@ edit_select_rep::selection_set (string key, tree t, bool persistant) {
   string mode= get_env_string (MODE);
   string lan = get_env_string (MODE_LANGUAGE (mode));
   tree sel= tuple ("texmacs", t, mode, lan);
-/*TODO: add mode="graphics" somewhere in the context of the <graphics>
-    tag. To be done when implementing the different embeddings for
-    nicely copying graphics into text, text into graphics, etc.
- */
+  /* TODO: add mode="graphics" somewhere in the context of the <graphics>
+     tag. To be done when implementing the different embeddings for
+     nicely copying graphics into text, text into graphics, etc. */
   string s;
-  if (key == "primary") {
+  if (key == "primary" || key == "mouse") {
     if (selection_export == "verbatim") t= exec_texmacs (t, tp);
     if (selection_export == "html") t= exec_html (t, tp);
     if (selection_export == "latex") t= exec_latex (t, tp);
@@ -565,8 +599,8 @@ edit_select_rep::selection_set (string key, tree t, bool persistant) {
     s= tree_to_generic (t, selection_export * "-snippet");
     s= selection_encode (lan, s);
   }
-  if (dis->set_selection (widget (this), key, sel, s) &&
-      (!persistant)) selection_cancel ();
+  if (::set_selection (key, sel, s) && !persistant)
+    selection_cancel ();
 }
 
 void
@@ -594,7 +628,8 @@ edit_select_rep::selection_copy (string key) {
 
 void
 edit_select_rep::selection_paste (string key) {
-  tree t= copy (dis->get_selection (widget (this), key));
+  tree t; string s;
+  (void) ::get_selection (key, t, s);
   if (inside_active_graphics ()) {
     if (is_tuple (t, "texmacs", 3))
       call ("graphics-paste", t[1]);
@@ -626,7 +661,7 @@ edit_select_rep::selection_paste (string key) {
       if (is_func (t[1], TFORMAT) || is_func (t[1], TABLE)) {
 	int row, col;
 	path fp= search_format (row, col);
-	if (nil (fp)) insert_tree (compound (copy (TABULAR), t[1]));
+	if (is_nil (fp)) insert_tree (compound (copy (TABULAR), t[1]));
 	else table_write_subtable (fp, row, col, t[1]);
       }
       else insert_tree (t[1]);
@@ -636,7 +671,7 @@ edit_select_rep::selection_paste (string key) {
 
 void
 edit_select_rep::selection_clear (string key) {
-  dis->clear_selection (key);
+  ::clear_selection (key);
 }
 
 void
@@ -743,7 +778,7 @@ edit_select_rep::raw_cut (path p1, path p2) {
     cerr << "p = " << p << "\n";
     cerr << "p1= " << p1 << "\n";
     cerr << "p2= " << p2 << "\n";
-    fatal_error ("invalid cut", "edit_select_rep::raw_cut");
+    FAILED ("invalid cut");
   }
 
   if (is_atomic (t)) {
@@ -757,7 +792,7 @@ edit_select_rep::raw_cut (path p1, path p2) {
       cerr << "p = " << p << "\n";
       cerr << "p1= " << p1 << "\n";
       cerr << "p2= " << p2 << "\n";
-      fatal_error ("invalid object cut", "edit_select_rep::raw_cut");
+      FAILED ("invalid object cut");
     }
     assign (p, "");
   }
