@@ -4,10 +4,9 @@
 * DESCRIPTION: abstract TeXmacs editors
 * COPYRIGHT  : (C) 1999  Joris van der Hoeven
 *******************************************************************************
-* This software falls under the GNU general public license and comes WITHOUT
-* ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for more details.
-* If you don't have this file, write to the Free Software Foundation, Inc.,
-* 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+* This software falls under the GNU general public license version 3 or later.
+* It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+* in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ******************************************************************************/
 
 #ifndef EDITOR_H
@@ -16,8 +15,12 @@
 #ifdef AQUATEXMACS
 #include "Cocoa/aqua_simple_widget.h"
 #else
+#ifdef QTTEXMACS
+#include "Qt/qt_simple_widget.hpp"
+#else
 #include "Widkit/simple_wk_widget.hpp"
 #endif
+#endif
 #include "server.hpp"
 #include "scheme.hpp"
 #include "drd_info.hpp"
@@ -140,6 +143,7 @@ public:
   virtual bool complete_try () = 0;
   virtual void complete_start (string prefix, array<string> compls) = 0;
   virtual bool complete_keypress (string key) = 0;
+  virtual bool session_complete_try (tree t) = 0;
   virtual void mouse_any (string s, SI x, SI y, int mods, time_t t) = 0;
   virtual void mouse_click (SI x, SI y) = 0;
   virtual bool mouse_extra_click (SI x, SI y) = 0;
@@ -250,15 +254,6 @@ public:
   virtual void     typeset_invalidate_all () = 0;
 
   /* public routines from edit_modify */
-  virtual void assign (path p, tree u) = 0;
-  virtual void insert (path p, tree u) = 0;
-  virtual void remove (path p, int nr) = 0;
-  virtual void split (path p) = 0;
-  virtual void join (path p) = 0;
-  virtual void assign_node (path p, tree_label op) = 0;
-  virtual void insert_node (path p, tree t) = 0;
-  virtual void remove_node (path p) = 0;
-  virtual void finished (path p) = 0;
   virtual void notify_assign (path p, tree u) = 0;
   virtual void notify_insert (path p, tree u) = 0;
   virtual void notify_remove (path p, int nr) = 0;
@@ -377,39 +372,6 @@ public:
   virtual void temp_proof_fix () = 0;
 
   /* public routines from edit_process */
-  virtual void process_mutators () = 0;
-  virtual path get_mutator_path () = 0;
-  virtual time_t get_mutator_time () = 0;
-  virtual void invalidate_mutators () = 0;
-  virtual void insert_mutator (tree body, string cmd) = 0;
-
-  virtual void make_session (string lan, string session) = 0;
-  virtual void start_input (string lan, string session, path p) = 0;
-  virtual void process_input () = 0;
-  virtual void start_output () = 0;
-  virtual void session_message (string l, string r) = 0;
-  virtual void session_use_math_input (bool flag) = 0;
-  virtual bool session_is_using_math_input () = 0;
-  virtual int  status_connection () = 0;
-  virtual bool busy_connection () = 0;
-  virtual void interrupt_connection () = 0;
-  virtual void stop_connection () = 0;
-
-  virtual void session_go_up () = 0;
-  virtual void session_go_down () = 0;
-  virtual void session_go_page_up () = 0;
-  virtual void session_go_page_down () = 0;
-  virtual void session_remove (bool forward) = 0;
-  virtual void session_insert_text_field () = 0;
-  virtual void session_insert_input_below () = 0;
-  virtual void session_insert_input_above () = 0;
-  virtual void session_fold_input () = 0;
-  virtual void session_remove_input (bool forward) = 0;
-  virtual void session_remove_all_outputs () = 0;
-  virtual void session_remove_previous_output () = 0;
-  virtual void session_split () = 0;
-  virtual bool session_complete_try () = 0;
-
   virtual void generate_bibliography (string bib, string sty, string fname)= 0;
   virtual void generate_table_of_contents (string toc) = 0;
   virtual void generate_index (string idx) = 0;
@@ -426,6 +388,7 @@ public:
   virtual void select_from_cursor_if_active () = 0;
   virtual void select_from_keyboard (bool flag) = 0;
   virtual void select_from_shift_keyboard () = 0;
+  virtual void select_enlarge_text () = 0;
   virtual void select_enlarge () = 0;
   virtual void select_enlarge_environmental () = 0;
 
