@@ -5,10 +5,9 @@
 ;; DESCRIPTION : Building basic glue for the server
 ;; COPYRIGHT   : (C) 1999  Joris van der Hoeven
 ;;
-;; This software falls under the GNU general public licence and comes WITHOUT
-;; ANY WARRENTY WHATSOEVER. See the file $TEXMACS_PATH/LICENCE for details.
-;; If you don't have this file, write to the Free Software Foundation, Inc.,
-;; 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+;; This software falls under the GNU general public license version 3 or later.
+;; It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+;; in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ;;
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
@@ -18,10 +17,6 @@
   "get_server()->"
   "initialize_glue_server"
 
-  (set-input-language set_input_language (void string))
-  (get-input-language get_input_language (string))
-  (set-output-language set_output_language (void string))
-  (get-output-language get_output_language (string))
   (insert-kbd-wildcard insert_kbd_wildcard (void string string bool bool bool))
   (set-variant-keys set_variant_keys (void string string))
   (kbd-pre-rewrite kbd_pre_rewrite (string string))
@@ -43,7 +38,6 @@
   (set-shrinking-factor set_shrinking_factor (void int))
   (get-shrinking-factor get_shrinking_factor (int))
 
-  (exec-delayed exec_delayed (void object))
   (shell shell (void string))
   (dialogue-end dialogue_end (void))
   (choose-file choose_file (void object string string))
@@ -101,7 +95,6 @@
   (texmacs-save-buffer save_buffer (void url string))
   (auto-save auto_save (void))
   
-  (color get_color (int string))
   (get-style-menu get_style_menu (object))
   (get-add-package-menu get_add_package_menu (object))
   (get-remove-package-menu get_remove_package_menu (object))
@@ -121,7 +114,5 @@
   (set-message set_message (void string string))
   (set-message-temp set_message (void string string bool))
   (recall-message recall_message (void))
-  (translate translate (string string string string))
   (yes? is_yes (bool string))
-  (quit-TeXmacs quit (void))
-  (package-evaluate evaluate (tree string string content)))
+  (quit-TeXmacs quit (void)))
