@@ -4,10 +4,9 @@
 * DESCRIPTION: Glue for linking TeXmacs commands to guile
 * COPYRIGHT  : (C) 1999  Joris van der Hoeven
 *******************************************************************************
-* This software falls under the GNU general public license and comes WITHOUT
-* ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for more details.
-* If you don't have this file, write to the Free Software Foundation, Inc.,
-* 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+* This software falls under the GNU general public license version 3 or later.
+* It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+* in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ******************************************************************************/
 
 #include <tm_configure.hpp>
@@ -75,6 +74,24 @@ texmacs_version (string which) {
   return TEXMACS_VERSION;
 }
 
+bool
+gui_is_x () {
+#ifdef QTTEXMACS
+  return false;
+#else
+  return true;
+#endif
+}
+
+bool
+gui_is_qt () {
+#ifdef QTTEXMACS
+  return true;
+#else
+  return false;
+#endif
+}
+
 bool
 os_win32 () {
 #ifdef OS_WIN32
@@ -84,6 +101,15 @@ os_win32 () {
 #endif
 }
 
+bool
+os_mingw () {
+#ifdef __MINGW32__
+  return true;
+#else
+  return false;
+#endif
+}
+
 void
 win32_display (string s) {
   cout << s;
@@ -184,7 +210,7 @@ SCM
 string_to_scm (string s) {
   char* _s= as_charp (s);
   SCM r= scm_str2scm (_s, N(s));
-  delete[] _s;
+  tm_delete_array (_s);
   return r;
 }
 
@@ -212,7 +238,7 @@ SCM
 symbol_to_scm (string s) {
   char* _s= as_charp (s);
   SCM r= scm_symbol2scm (_s);
-  delete[] _s;
+  tm_delete_array (_s);
   return r;
 }
 
@@ -266,7 +292,7 @@ scm_is_tree (SCM t) {
 SCM
 tree_to_scm (tree t) {
   SCM tree_smob;
-  SET_SMOB (tree_smob, (void*) (new tree (t)), (SCM) tree_tag);
+  SET_SMOB (tree_smob, (void*) (tm_new<tree> (t)), (SCM) tree_tag);
   return tree_smob;
 }
 
@@ -284,7 +310,7 @@ mark_tree (SCM tree_smob) {
 static scm_sizet
 free_tree (SCM tree_smob) {
   tree *ptr = (tree *) SCM_CDR (tree_smob);
-  delete ptr;
+  tm_delete (ptr);
   return 0;
 }
 
@@ -361,19 +387,14 @@ tree_child_insert (tree t, int pos, tree x) {
 * Document modification routines
 ******************************************************************************/
 
-static inline bool
-ip_attached (path ip) {
-  return is_nil (ip) || last_item (ip) != DETACHED;
-}
+extern tree the_et;
 
 tree
 tree_assign (tree r, tree t) {
-  path ip= obtain_ip (r);
-  //cout << "Assign " << r << ", " << t << " at " << ip << "\n";
+  path ip= copy (obtain_ip (r));
   if (ip_attached (ip)) {
-    path p= reverse (ip);
-    get_server()->get_editor()->assign (p, copy (t));
-    return get_server()->get_editor()->the_subtree (p);
+    assign (reverse (ip), t);
+    return subtree (the_et, reverse (ip));
   }
   else {
     assign (r, t);
@@ -383,66 +404,75 @@ tree_assign (tree r, tree t) {
 
 tree
 tree_insert (tree r, int pos, tree t) {
-  path ip= obtain_ip (r);
-  //cout << "Insert " << r << ", " << pos << ", " << t
-  //     << " at " << ip << "\n";
-  if (ip_attached (ip))
-    get_server()->get_editor()->insert (reverse (ip) * pos, copy (t));
-  else insert (r, pos, t);
-  return r;
+  path ip= copy (obtain_ip (r));
+  if (ip_attached (ip)) {
+    insert (reverse (path (pos, ip)), t);
+    return subtree (the_et, reverse (ip));
+  }
+  else {
+    insert (r, pos, t);
+    return r;
+  }
 }
 
 tree
 tree_remove (tree r, int pos, int nr) {
-  path ip= obtain_ip (r);
-  //cout << "Remove " << r << ", " << pos << ", " << nr
-  //     << " at " << ip << "\n";
-  if (ip_attached (ip))
-    get_server()->get_editor()->remove (reverse (ip) * pos, nr);
-  else remove (r, pos, nr);
-  return r;
+  path ip= copy (obtain_ip (r));
+  if (ip_attached (ip)) {
+    remove (reverse (path (pos, ip)), nr);
+    return subtree (the_et, reverse (ip));
+  }
+  else {
+    remove (r, pos, nr);
+    return r;
+  }
 }
 
 tree
 tree_split (tree r, int pos, int at) {
-  path ip= obtain_ip (r);
-  //cout << "Split " << r << ", " << pos << ", " << at
-  //     << " at " << ip << "\n";
-  if (ip_attached (ip))
-    get_server()->get_editor()->split (reverse (ip) * path (pos, at));
-  else split (r, pos, at);
-  return r;
+  path ip= copy (obtain_ip (r));
+  if (ip_attached (ip)) {
+    split (reverse (path (at, pos, ip)));
+    return subtree (the_et, reverse (ip));
+  }
+  else {
+    split (r, pos, at);
+    return r;
+  }
 }
 
 tree
 tree_join (tree r, int pos) {
-  path ip= obtain_ip (r);
-  //cout << "Join " << r << ", " << pos << " at " << ip << "\n";
-  if (ip_attached (ip))
-    get_server()->get_editor()->join (reverse (ip) * pos);
-  else join (r, pos);
-  return r;
+  path ip= copy (obtain_ip (r));
+  if (ip_attached (ip)) {
+    join (reverse (path (pos, ip)));
+    return subtree (the_et, reverse (ip));
+  }
+  else {
+    join (r, pos);
+    return r;
+  }
 }
 
 tree
 tree_assign_node (tree r, tree_label op) {
-  path ip= obtain_ip (r);
-  //cout << "Assign node " << r << ", " << tree (op) << " at " << ip << "\n";
-  if (ip_attached (ip))
-    get_server()->get_editor()->assign_node (reverse (ip), op);
-  else assign_node (r, op);
-  return r;
+  path ip= copy (obtain_ip (r));
+  if (ip_attached (ip)) {
+    assign_node (reverse (ip), op);
+    return subtree (the_et, reverse (ip));
+  }
+  else {
+    assign_node (r, op);
+    return r;
+  }
 }
 
 tree
 tree_insert_node (tree r, int pos, tree t) {
-  path ip= obtain_ip (r);
-  //cout << "Insert node " << r << ", " << pos << ", " << t
-  //     << " at " << ip << "\n";
+  path ip= copy (obtain_ip (r));
   if (ip_attached (ip)) {
-    path p= reverse (ip);
-    get_server()->get_editor()->insert_node (p * pos, copy (t));
-    return get_server()->get_editor()->the_subtree (p);
+    insert_node (reverse (path (pos, ip)), t);
+    return subtree (the_et, reverse (ip));
   }
   else {
     insert_node (r, pos, t);
@@ -452,12 +482,10 @@ tree_insert_node (tree r, int pos, tree t) {
 
 tree
 tree_remove_node (tree r, int pos) {
-  path ip= obtain_ip (r);
-  //cout << "Remove node " << r << ", " << pos << " at " << ip << "\n";
+  path ip= copy (obtain_ip (r));
   if (ip_attached (ip)) {
-    path p= reverse (ip);
-    get_server()->get_editor()->remove_node (p * pos);
-    return get_server()->get_editor()->the_subtree (p);
+    remove_node (reverse (path (pos, ip)));
+    return subtree (the_et, reverse (ip));
   }
   else {
     remove_node (r, pos);
@@ -594,7 +622,7 @@ static long observer_tag;
 /*static*/ SCM
 observer_to_scm (observer o) {
   SCM observer_smob;
-  SET_SMOB (observer_smob, (void*) (new observer (o)), (SCM) observer_tag);
+  SET_SMOB (observer_smob, (void*) (tm_new<observer> (o)), (SCM) observer_tag);
   return observer_smob;
 }
 
@@ -612,7 +640,7 @@ mark_observer (SCM observer_smob) {
 static scm_sizet
 free_observer (SCM observer_smob) {
   observer *ptr = (observer *) SCM_CDR (observer_smob);
-  delete ptr;
+  tm_delete (ptr);
   return 0;
 }
 
@@ -654,7 +682,7 @@ scm_is_widget (SCM wid) {
 static SCM
 widget_to_scm (widget wid) {
   SCM widget_smob;
-  SET_SMOB (widget_smob, (void*) (new widget (wid)), (SCM) widget_tag);
+  SET_SMOB (widget_smob, (void*) (tm_new<widget> (wid)), (SCM) widget_tag);
   return widget_smob;
 }
 
@@ -672,7 +700,7 @@ mark_widget (SCM widget_smob) {
 static scm_sizet
 free_widget (SCM widget_smob) {
   widget *ptr = (widget *) SCM_CDR (widget_smob);
-  delete ptr;
+  tm_delete (ptr);
   return 0;
 }
 
@@ -707,7 +735,7 @@ static SCM
 promise_widget_to_scm (promise_widget pw) {
   SCM promise_widget_smob;
   SET_SMOB (promise_widget_smob,
-	    (void*) (new promise_widget (pw)),
+	    (void*) (tm_new<promise_widget> (pw)),
 	    (SCM) promise_widget_tag);
   return promise_widget_smob;
 }
@@ -726,7 +754,7 @@ mark_promise_widget (SCM promise_widget_smob) {
 static scm_sizet
 free_promise_widget (SCM promise_widget_smob) {
   promise_widget *ptr = (promise_widget *) SCM_CDR (promise_widget_smob);
-  delete ptr;
+  tm_delete (ptr);
   // should be replaced by total size of the widget factory
   return 0;
 }
@@ -761,7 +789,7 @@ static long command_tag;
 static SCM
 command_to_scm (command cmd) {
   SCM command_smob;
-  SET_SMOB (command_smob, (void*) (new command (cmd)), (SCM) command_tag);
+  SET_SMOB (command_smob, (void*) (tm_new<command> (cmd)), (SCM) command_tag);
   return command_smob;
 }
 
@@ -779,7 +807,7 @@ mark_command (SCM command_smob) {
 static scm_sizet
 free_command (SCM command_smob) {
   command *ptr = (command *) SCM_CDR (command_smob);
-  delete ptr;
+  tm_delete (ptr);
   return 0;
 }
 
@@ -815,14 +843,18 @@ scm_is_url (SCM u) {
 SCM
 url_to_scm (url u) {
   SCM url_smob;
-  SET_SMOB (url_smob, (void*) (new url (u)), (SCM) url_tag);
+  SET_SMOB (url_smob, (void*) (tm_new<url> (u)), (SCM) url_tag);
   return url_smob;
 }
 
 url
 scm_to_url (SCM url_smob) {
   if (scm_is_string (url_smob))
+#ifdef __MINGW32__
+    return url_system(scm_to_string (url_smob));
+#else
     return scm_to_string (url_smob);
+#endif
   return *((url*) SCM_CDR (url_smob));
 }
 
@@ -835,7 +867,7 @@ mark_url (SCM url_smob) {
 static scm_sizet
 free_url (SCM url_smob) {
   url *ptr = (url *) SCM_CDR (url_smob);
-  delete ptr;
+  tm_delete (ptr);
   return 0;
 }
 
