@@ -4,10 +4,9 @@
 * DESCRIPTION: Initialization of the X11 window manager
 * COPYRIGHT  : (C) 1999  Joris van der Hoeven
 *******************************************************************************
-* This software falls under the GNU general public license and comes WITHOUT
-* ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for more details.
-* If you don't have this file, write to the Free Software Foundation, Inc.,
-* 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+* This software falls under the GNU general public license version 3 or later.
+* It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+* in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ******************************************************************************/
 
 #include "X11/x_window.hpp"
@@ -96,7 +95,7 @@ x_init_color_map () {
   if (true_color) return;
 
   int i, r, g, b;
-  the_gui->cmap= new color [CTOTAL];
+  the_gui->cmap= tm_new_array<color> (CTOTAL);
 
   for (i=0; i<=GREYS; i++)
     the_gui->cmap[i]=
@@ -444,9 +443,9 @@ x_gui_rep::initialize_keyboard_pointer () {
   Map (XK_Cyrillic_E,   "\xdd");
   Map (XK_Cyrillic_YU,  "\xde");
   Map (XK_Cyrillic_YA,  "\xdf");
-  
+
   //Ukrainian letters in T2A encoding
-  Map (XK_Ukrainian_i,   "i"); // Fall back! 
+  Map (XK_Ukrainian_i,   "i"); // Fall back!
   Map (XK_Ukrainian_I,   "I"); // Fall back!
   Map (XK_Ukrainian_yi,   "\xa8");
   Map (XK_Ukrainian_YI,   "\x88");
@@ -809,11 +808,11 @@ x_gui_rep::x_gui_rep (int argc2, char** argv2):
   character_bitmap (NULL), character_pixmap ((pointer) 0),
   xpm_bitmap (0), xpm_pixmap (0),
   lower_key (""), upper_key (""),
-  selection (NULL), selection_t ("none"), selection_s ("")
+  selection_t ("none"), selection_s ("")
 {
   the_gui= this;
-  if ((dpy= XOpenDisplay (NULL)) == NULL)
-    fatal_error ("I failed to connect to Xserver", "x_gui_rep::x_gui_rep");
+  ASSERT ((dpy= XOpenDisplay (NULL)) != NULL,
+	  "failure to connect to Xserver");
   // XSynchronize (dpy, true);
 
   XGCValues values;
@@ -835,6 +834,9 @@ x_gui_rep::x_gui_rep (int argc2, char** argv2):
   interrupted        = false;
   interrupt_time     = texmacs_time ();
 
+  XA_CLIPBOARD = XInternAtom (dpy, "CLIPBOARD", false);
+  XA_TARGETS = XInternAtom (dpy, "TARGETS", false);
+
   if (XMatchVisualInfo (dpy, scr, depth, TrueColor, &visual) != 0) {
     if (visual.red_mask   == (255 << 16) &&
 	visual.green_mask == (255 << 8) &&
@@ -857,14 +859,13 @@ x_gui_rep::~x_gui_rep () {
   clear_selection ("primary");
   XFreeGC (dpy, gc);
   XCloseDisplay (dpy);
-  if (!true_color) delete[] cmap;
+  if (!true_color) tm_delete_array (cmap);
 }
 
 void
 gui_open (int argc2, char** argv2) {
-  if (the_gui != NULL)
-    fatal_error ("gui already open", "gui_open");
-  the_gui= new x_gui_rep (argc2, argv2);
+  ASSERT (the_gui == NULL, "gui already open");
+  the_gui= tm_new<x_gui_rep> (argc2, argv2);
 }
 
 void
@@ -874,9 +875,8 @@ gui_start_loop () {
 
 void
 gui_close () {
-  if (the_gui == NULL)
-    fatal_error ("gui not yet open", "gui_close");
-  delete the_gui;
+  ASSERT (the_gui != NULL, "gui not yet open");
+  tm_delete (the_gui);
   the_gui= NULL;
 }
 
