@@ -28,6 +28,7 @@
 *     in a slightly different way with respect to concatenation.
 *     For instance http://www.texmacs.org/Web * file:///tmp would yield
 *     file:///tmp, where as http://www.texmacs.org/Web * /tmp yields
+*     http://www.texmacs.org/tmp
 *******************************************************************************
 * There are several formats for parsing (and printing) urls:
 *   - System format: the usual format on your operating system.
@@ -52,10 +53,9 @@
 * since such names may be the names of temporary files,
 * which may be destroyed soon afterwards.
 *******************************************************************************
-* This software falls under the GNU general public license and comes WITHOUT
-* ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for more details.
-* If you don't have this file, write to the Free Software Foundation, Inc.,
-* 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+* This software falls under the GNU general public license version 3 or later.
+* It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+* in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ******************************************************************************/
 
 #include "boot.hpp"
@@ -65,7 +65,11 @@
 #include "file.hpp"
 #include "analyze.hpp"
 
-#ifdef OS_WIN32
+#if defined(OS_WIN32)  || defined(__MINGW32__)
+#define WINPATHS
+#endif
+
+#ifdef WINPATHS
 #define URL_CONCATER  '\\'
 #define URL_SEPARATOR ';'
 #else
@@ -131,7 +135,7 @@ url_ramdisc (string contents) {
 static url
 url_default (string name, int type= URL_SYSTEM) {
   url u= url_get_name (name, type);
-#ifdef OS_WIN32
+#ifdef WINPATHS
   // FIXME: this hack seems a bit too simple
   if (is_concat (u) && (u[2]->t == "")) u= u[1];
   // cout << name << " -> " << url_root ("default") * u << "\n";
@@ -194,7 +198,7 @@ heuristic_is_path (string name, int type) {
 
 static bool
 heuristic_is_default (string name, int type) {
-#ifdef OS_WIN32
+#ifdef WINPATHS
   // FIXME: we probably should take into account 'type' too
   if (N(name) < 2) return false;
   if ((name[0] == '\\') && (name[1] == '\\')) return true;
@@ -262,10 +266,10 @@ url_standard (string dir, string name) {
   return url_standard (dir) * url_standard (name);
 }
 
-url::url (const char* name): rep (new url_rep (url_unix (name)->t)) {}
-url::url (string name): rep (new url_rep (url_unix (name)->t)) {}
+url::url (const char* name): rep (tm_new<url_rep> (url_unix (name)->t)) {}
+url::url (string name): rep (tm_new<url_rep> (url_unix (name)->t)) {}
 url::url (string path_name, string name):
-  rep (new url_rep (url_unix (path_name, name)->t)) {}
+  rep (tm_new<url_rep> (url_unix (path_name, name)->t)) {}
 
 /******************************************************************************
 * Computational url constructors
@@ -274,7 +278,7 @@ url::url (string path_name, string name):
 static bool
 is_semi_root (url u) {
   // url u such that u/.. == u (website or windows drive name)
-#ifdef OS_WIN32
+#ifdef WINPATHS
   return is_concat (u) && is_root (u[1]) && is_atomic (u[2]);
 #else
   return is_concat (u) && is_root_web (u[1]) && is_atomic (u[2]);
@@ -437,7 +441,7 @@ as_string (url u, int type) {
     if ((!is_name (u[1])) && (!is_root (u[1]))) s1= "{" * s1 * "}";
     if ((!is_concat (u[2])) && (!is_atomic (u[2])) && (!is_wildcard (u[2], 1)))
       s2= "{" * s2 * "}";
-#ifdef OS_WIN32
+#ifdef WINPATHS
     if (is_semi_root (u)) {
       if (ends (s2, ":")) return s2 * "\\";
       else return s2;
@@ -451,14 +455,14 @@ as_string (url u, int type) {
     string s2= as_string (u[2], type);
     if (!is_name_in_path (u[1])) s1= "{" * s1 * "}";
     if ((!is_or (u[2])) && (!is_name_in_path (u[2]))) s2= "{" * s2 * "}";
-#ifdef OS_WIN32
+#ifdef WINPATHS
     if (type == URL_STANDARD) return s1 * ":" * s2;
     else return s1 * string (URL_SEPARATOR) * s2;
 #else
     return s1 * string (URL_SEPARATOR) * s2;
 #endif
   }
-#ifdef OS_WIN32
+#ifdef WINPATHS
   if (is_root (u, "default")) {
     int stype= type;
     if (is_root (u[1]) && (!is_root (u[1], "default"))) stype= URL_STANDARD;
@@ -471,8 +475,8 @@ as_string (url u, int type) {
   if (is_root (u)) return u[1]->t->label * ":/";
   if (is_wildcard (u, 0)) return "**";
   if (is_wildcard (u, 1)) return u->t[1]->label;
-  fatal_error ("bad url", "as_string", "url.cpp");
-  return ""; // NOT REACHED
+  FAILED ("bad url");
+  return "";
 }
 
 ostream&
@@ -523,8 +527,8 @@ glue (url u, string s) {
   if (is_or (u)) return glue (u[1], s) | glue (u[2], s);
   cerr << "\nu= " << u << "\n";
   cerr << "s= " << s << "\n";
-  fatal_error ("can't glue string to url", "glue", "url.cpp");
-  return u; // NOT REACHED
+  FAILED ("can't glue string to url");
+  return u;
 }
 
 url
@@ -535,8 +539,8 @@ unglue (url u, int nr) {
   if (is_or (u)) return unglue (u[1], nr) | unglue (u[2], nr);
   cerr << "\nu= " << u << "\n";
   cerr << "nr= " << nr << "\n";
-  fatal_error ("can't unglue from url", "unglue", "url.cpp");
-  return u; // NOT REACHED
+  FAILED ("can't unglue from url");
+  return u;
 }
 
 url
@@ -554,7 +558,7 @@ relative (url base, url u) {
 
 url
 delta_sub (url base, url u) {
-#ifdef OS_WIN32
+#ifdef WINPATHS
   if (is_atomic (base) || heuristic_is_default (as_string (base), URL_SYSTEM))
     return u;
 #else
@@ -701,7 +705,7 @@ complete (url base, url u, string filter, bool flag) {
   if (is_none (u)) return u;
   if ((!is_root (base)) && (!is_rooted_name (base))) {
     cerr << "base= " << base << LF;
-    fatal_error ("invalid base url", "complete", "url.cpp");
+    FAILED ("invalid base url");
   }
   if (is_name (u) || (is_concat (u) && is_root (u[1]) && is_name (u[2]))) {
     url comp= base * u;
@@ -714,8 +718,8 @@ complete (url base, url u, string filter, bool flag) {
       return url_none ();
     }
     cerr << LF << "base= " << base << LF;
-    if (!is_rooted (comp)) fatal_error ("unrooted url", "complete", "url.cpp");
-    else fatal_error ("bad protocol in url", "complete", "url.cpp");
+    ASSERT (is_rooted (comp), "unrooted url");
+    FAILED ("bad protocol in url");
   }
   if (is_root (u)) {
     // FIXME: test filter flags here
@@ -735,8 +739,7 @@ complete (url base, url u, string filter, bool flag) {
     // FIXME: ret= ret | ... is unefficient (quadratic) in main loop
     if (!(is_rooted (base, "default") || is_rooted (base, "file"))) {
       cerr << LF << "base= " << base << LF;
-      fatal_error ("wildcards only implemented for files",
-		   "complete", "url.cpp");
+      FAILED ("wildcards only implemented for files");
     }
     url ret= url_none ();
     if (is_wildcard (u, 0) && is_of_type (base, filter)) ret= url_here ();
@@ -754,8 +757,8 @@ complete (url base, url u, string filter, bool flag) {
     return ret;
   }
   cout << LF << "url= " << u << LF;
-  fatal_error ("bad url", "complete", "url.cpp");
-  return u; // NOT REACHED
+  FAILED ("bad url");
+  return u;
 }
 
 url
@@ -837,7 +840,7 @@ string
 concretize (url u) {
   // This routine transforms a resolved url into a system file name.
   // In the case of distant files from the web, a local copy is created.
-#ifdef OS_WIN32
+#ifdef WINPATHS
   // FIXME: this fix seems strange;
   // to start with, the if condition is not respected
   string s = as_string (u);
@@ -855,7 +858,7 @@ concretize (url u) {
   if (is_wildcard (u, 1)) return u->t[1]->label;
   cerr << "TeXmacs] couldn't concretize " << u->t << LF;
   // cerr << "\nu= " << u << LF;
-  // fatal_error ("url has no root", "concretize", "url.cpp");
+  // FAILED ("url has no root");
   return "xxx";
 }
 
@@ -865,7 +868,7 @@ materialize (url u, string filter) {
   url r= resolve (u, filter);
   if (!(is_rooted (u) || is_here (u) || is_parent (u))) {
     cerr << "\nu= " << u << LF;
-    fatal_error ("url could not be resolved", "concrete_resolve", "url.cpp");
+    FAILED ("url could not be resolved");
   }
   return concretize (r);
 }
