@@ -4,10 +4,9 @@
 * DESCRIPTION: file handling
 * COPYRIGHT  : (C) 1999  Joris van der Hoeven
 *******************************************************************************
-* This software falls under the GNU general public license and comes WITHOUT
-* ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for more details.
-* If you don't have this file, write to the Free Software Foundation, Inc.,
-* 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+* This software falls under the GNU general public license version 3 or later.
+* It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+* in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ******************************************************************************/
 
 #ifndef FILE_H
@@ -38,26 +37,23 @@ inline void system (string which, url u1) {
   system (which * " " * sys_concretize (u1)); }
 inline void system (string which, url u1, url u2) {
   system (which * " " * sys_concretize (u1) * " " * sys_concretize (u2)); }
-inline void system (string which, url u1, char* post) {
+inline void system (string which, url u1, const char* post) {
   system (which * " " * sys_concretize (u1) * " " * post); }
-inline void system (string which, url u1, char* sep, url u2) {
+inline void system (string which, url u1, const char* sep, url u2) {
   system (which * " " * sys_concretize (u1) * " " * sep *
 	          " " * sys_concretize (u2)); }
 inline string eval_system (string which, url u1) {
   return eval_system (which * " " * concretize (u1)); }
 inline string eval_system (string which, url u1, url u2) {
   return eval_system (which * " " * concretize (u1) * " " * concretize (u2)); }
-inline void move (url from, url to) { system ("mv", from, to); }
-inline void copy (url from, url to) { system ("cp", from, to); }
-inline void append (url from, url to) { system ("cat", from, ">>", to); }
-inline void remove (url what) { system ("rm -f", what); }
-#ifdef OS_WIN32
-inline void mkdir (url dir) { system ("mkdir", dir); }
-#else
-inline void mkdir (url dir) { system ("mkdir -p", dir); }
-#endif
 
+void move (url from, url to);
+void copy (url from, url to);
+void remove (url what);
+void mkdir (url dir);
+void change_mode (url u, int mode);
 void ps2pdf (url u1, url u2);
+
 int search_score (url u, array<string> a);
 
 #endif // defined FILE_H
