@@ -4,10 +4,9 @@
 * DESCRIPTION: The TeXmacs server
 * COPYRIGHT  : (C) 1999  Joris van der Hoeven
 *******************************************************************************
-* This software falls under the GNU general public license and comes WITHOUT
-* ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for more details.
-* If you don't have this file, write to the Free Software Foundation, Inc.,
-* 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+* This software falls under the GNU general public license version 3 or later.
+* It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+* in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ******************************************************************************/
 
 #include "tm_server.hpp"
@@ -19,6 +18,7 @@
 #include "pipe_link.hpp"
 #include "socket_link.hpp"
 #include "socket_server.hpp"
+#include "dictionary.hpp"
 
 server* the_server= NULL;
 bool texmacs_started= false;
@@ -26,34 +26,15 @@ url tm_init_file= url_none ();
 url my_init_file= url_none ();
 string my_init_cmds= "";
 
+/******************************************************************************
+* Execution of commands
+******************************************************************************/
+
 void reset_inclusions ();
 extern string printing_dpi;
 extern string printing_cmd;
 extern string printing_on;
 extern int nr_windows;
-extern window (*get_current_window) (void);
-
-/******************************************************************************
-* Creation of TeXmacs window
-******************************************************************************/
-
-int geometry_w= 800, geometry_h= 600;
-int geometry_x= 0  , geometry_y= 0;
-
-window
-texmacs_window (widget wid, tree geom) {
-  int W, H;
-  int w= geometry_w, h= geometry_h;
-  int x= geometry_x, y= geometry_y;
-  if (is_tuple (geom) && N (geom) >= 2) {
-    w= as_int (geom[0]);
-    h= as_int (geom[1]);
-  }
-  wid->dis->get_extents (W, H); W /= PIXEL; H /= PIXEL;
-  if (x < 0) x= W + x + 1 - w;
-  if (y < 0) y= H + y + 1 - h;
-  return plain_window (wid, "TeXmacs", w*PIXEL, h*PIXEL, x*PIXEL, (-y)*PIXEL);
-}
 
 /******************************************************************************
 * Texmacs server constructor and destructor
@@ -72,17 +53,9 @@ texmacs_wait_handler (string message, string arg, int level) {
     (*the_server)->wait_handler (message, arg);
 }
 
-window
-texmacs_current_window () {
-  if (the_server == NULL)
-    fatal_error ("No server", "texmacs_current_window", "tm_server.cpp");
-  return (*the_server)->get_window()->win;
-}
-
 server
 get_server () {
-  if (the_server == NULL)
-    fatal_error ("TeXmacs server not yet started", "get_server");
+  ASSERT (the_server != NULL, "TeXmacs server not yet started");
   return *the_server;
 }
 
@@ -91,21 +64,24 @@ get_subtree (path p) {
   return get_server()->get_editor()->the_subtree (p);
 }
 
+void
+gui_set_output_language (string lan) {
+  set_output_language (lan);
+  gui_refresh ();
+}
+
 server_rep::server_rep () {}
 server_rep::~server_rep () {}
 
-tm_server_rep::tm_server_rep (display dis2):
-  dis (dis2), vw (NULL),
-  full_screen (false), full_screen_edit (false), def_sfactor (5),
+tm_server_rep::tm_server_rep ():
+  vw (NULL), def_sfactor (5),
   style_cache (hashmap<string,tree> (UNINIT)),
   style_drd (tree (COLLECTION))
 {
-  the_server= new server (this);
+  the_server= tm_new<server> (this);
   initialize_guile ();
-  set_interpose_handler (texmacs_interpose_handler);
+  gui_interpose (texmacs_interpose_handler);
   set_wait_handler (texmacs_wait_handler);
-  get_current_window= texmacs_current_window;
-  out_lan= dis->get_output_language ();
   if (is_none (tm_init_file))
     tm_init_file= "$TEXMACS_PATH/progs/init-texmacs.scm";
   if (is_none (my_init_file))
@@ -126,7 +102,7 @@ tm_server_rep::tm_server_rep (display dis2):
 }
 
 tm_server_rep::~tm_server_rep () {}
-server::server (display dis): rep (new tm_server_rep (dis)) {}
+server::server (): rep (tm_new<tm_server_rep> ()) {}
 
 /******************************************************************************
 * Get and set objects associated to server
@@ -137,20 +113,19 @@ tm_server_rep::get_server () {
   return this;
 }
 
-display
-tm_server_rep::get_display () {
-  return dis;
-}
-
 bool
 tm_server_rep::has_view () {
   return vw != NULL;
 }
 
+bool
+tm_server_rep::has_window () {
+  return vw != NULL && vw->win != NULL;
+}
+
 tm_view
 tm_server_rep::get_view (bool must_be_valid) {
-  if (must_be_valid && (vw==NULL))
-    fatal_error ("No active view", "tm_server_rep::get_meta");
+  ASSERT (!must_be_valid || vw != NULL, "no active view");
   return vw;
 }
 
@@ -177,22 +152,10 @@ tm_server_rep::get_editor () {
 tm_window
 tm_server_rep::get_window () {
   tm_view vw= get_view ();
-  if (vw->win==NULL)
-    fatal_error ("No window attached to view", "tm_server_rep::get_meta");
+  ASSERT (vw->win != NULL, "no window attached to view");
   return vw->win;
 }
 
-tm_widget
-tm_server_rep::get_meta () {
-  tm_window win= get_window ();
-  return win->wid;
-}
-
-color
-tm_server_rep::get_color (string s) {
-  return get_display () -> get_color (s);
-}
-
 int
 tm_server_rep::get_nr_windows () {
   return nr_windows;
@@ -207,7 +170,7 @@ compute_style_menu (url u, int kind) {
   if (is_or (u)) {
     string sep= "\n";
     if (is_atomic (u[1]) &&
-	((is_concat (u[2]) && (u[2][1] != "CVS")) ||
+	((is_concat (u[2]) && (u[2][1] != "CVS") && (u[2][1] != ".svn")) ||
 	 (is_or (u[2]) && is_concat (u[2][1]))))
       sep= "\n---\n";
     return
@@ -217,7 +180,8 @@ compute_style_menu (url u, int kind) {
   if (is_concat (u)) {
     string dir= upcase_first (as_string (u[1]));
     string sub= compute_style_menu (u[2], kind);
-    if ((dir == "Test") || (dir == "Obsolete") || (dir == "CVS")) return "";
+    if ((dir == "Test") || (dir == "Obsolete") ||
+	(dir == "CVS") || (dir == ".svn")) return "";
     return "(-> \"" * dir * "\" " * sub * ")";
   }
   if (is_atomic (u)) {
@@ -311,9 +275,9 @@ tm_server_rep::style_get_cache (
     url name ("$TEXMACS_HOME_PATH/system/cache", cache_file_name (style));
     if (exists (name) && (!load_string (name, s, false))) {
       // cout << "loaded " << name << LF;
-      tree pair= scheme_to_tree (s);
-      H= hashmap<string,tree> (UNINIT, pair[0]);
-      t= pair[1];
+      tree p= scheme_to_tree (s);
+      H= hashmap<string,tree> (UNINIT, p[0]);
+      t= p[1];
       style_cache (copy (style))= H;
       style_drd   (copy (style))= t;
       f= true;
@@ -321,85 +285,6 @@ tm_server_rep::style_get_cache (
   }
 }
 
-/******************************************************************************
-* Routines concerning the widget
-******************************************************************************/
-
-void
-tm_server_rep::get_visible (SI& x1, SI& y1, SI& x2, SI& y2) {
-  widget meta= (widget) get_meta ();
-  meta["canvas"] << ::get_visible (x1, y1, x2, y2);
-}
-
-void
-tm_server_rep::scroll_where (SI& x, SI& y) {
-  widget meta= (widget) get_meta ();
-  meta["canvas"] << get_coord2 ("scroll position", x, y);
-}
-
-void
-tm_server_rep::scroll_to (SI x, SI y) {
-  widget meta= (widget) get_meta ();
-  meta["canvas"] << set_scroll_pos (x, y);
-}
-
-void
-tm_server_rep::set_extents (SI x1, SI y1, SI x2, SI y2) {
-  widget meta= (widget) get_meta ();
-  meta["canvas"] << ::set_extents (x1, y1, x2, y2);
-}
-
-void
-tm_server_rep::set_left_footer (string s) {
-  if ((vw == NULL) || (vw->win == NULL)) return;
-  get_meta()->set_left_footer (s);
-}
-
-void
-tm_server_rep::set_right_footer (string s) {
-  if ((vw == NULL) || (vw->win == NULL)) return;
-  get_meta()->set_right_footer (s);
-}
-
-void
-tm_server_rep::set_message (string left, string right, bool temp) {
-  if ((vw == NULL) || (vw->win == NULL)) return;
-  get_editor()->set_message (left, right, temp);
-}
-
-void
-tm_server_rep::recall_message () {
-  if ((vw == NULL) || (vw->win == NULL)) return;
-  get_editor()->recall_message ();
-}
-
-void
-tm_server_rep::full_screen_mode (bool on, bool edit) {
-  widget meta= (widget) get_meta ();
-  if (on && !edit) {
-    show_header (false);
-    show_footer (false);
-  }
-  else {
-    show_header (true);
-    show_footer (true);
-  }
-  meta->win->full_screen (on);
-  get_editor()->full_screen_mode (on && !edit);
-  full_screen = on;
-  full_screen_edit = on && edit;
-}
-
-bool
-tm_server_rep::in_full_screen_mode () {
-  return full_screen && !full_screen_edit;
-}
-
-bool
-tm_server_rep::in_full_screen_edit_mode () {
-  return full_screen && full_screen_edit;
-}
-
 /******************************************************************************
 * Miscellaneous routines
 ******************************************************************************/
@@ -415,10 +300,6 @@ tm_server_rep::interpose_handler () {
   int i,j;
   for (i=0; i<N(bufs); i++) {
     tm_buffer buf= (tm_buffer) bufs[i];
-    for (j=0; j<N(buf->vws); j++) {
-      tm_view vw= (tm_view) buf->vws[j];
-      if (vw->win != NULL) vw->ed->process_mutators ();
-    }
     for (j=0; j<N(buf->vws); j++) {
       tm_view vw= (tm_view) buf->vws[j];
       if (vw->win != NULL) vw->ed->apply_changes ();
@@ -432,7 +313,7 @@ tm_server_rep::interpose_handler () {
 
 void
 tm_server_rep::wait_handler (string message, string arg) {
-  dis->set_wait_indicator (message, arg);
+  show_wait_indicator (get_window () -> win, message, arg);
 }
 
 void
@@ -453,7 +334,7 @@ tm_server_rep::focus_on_editor (editor ed) {
       }
     }
   }
-  fatal_error ("Invalid situation", "tm_server_rep::focus_on_editor");
+  FAILED ("invalid situation");
 }
 
 void
@@ -488,7 +369,7 @@ tm_server_rep::get_default_shrinking_factor () {
 
 void
 tm_server_rep::image_gc (string which) {
-  dis->image_gc (which);
+  ::image_gc (which);
   typeset_update_all ();
 }
 
@@ -519,12 +400,6 @@ tm_server_rep::typeset_update_all () {
   }
 }
 
-string
-tm_server_rep::translate (string which, string from, string to) {
-  display dis= get_display ();
-  return dis->translate (which, from, to);
-}
-
 bool
 tm_server_rep::is_yes (string s) {
   s= locase_all (s);
@@ -545,39 +420,6 @@ tm_server_rep::quit () {
   exit (0);
 }
 
-/******************************************************************************
-* Extern packages
-******************************************************************************/
-
-tree
-tm_server_rep::evaluate (string name, string session, tree expr) {
-  if (name == "scheme") {
-    string s= tree_to_verbatim (expr);
-    object x= ::eval (s);
-    if (is_tree (x) && as_bool (call ("session-scheme-trees?")))
-      return as_tree (x);
-    else if (as_bool (call ("session-scheme-math?"))) {
-      object y= call ("cas->stree", x);
-      if (as_bool (call ("tm?", y)))
-	return compound ("math", as_tree (call ("tm->tree", y)));
-    }
-    string r= object_to_string (x);
-    if (r == "#<unspecified>") r= "";
-    return verbatim_to_tree (r);
-  }
-  if (!connection_declared (name)) {
-    set_message ("Package#'" * name * "'#not declared",
-		 "Evaluate#'" * name * "'#expression");
-    return "";
-  }
-  if (connection_status (name, session) == CONNECTION_DEAD) {
-    string r= connection_start (name, session);
-    set_message (r, "Started#'" * name * "'");
-    if (connection_status (name, session) == CONNECTION_DEAD) return "";
-  }
-  return connection_eval (name, session, expr);
-}
-
 /******************************************************************************
 * System commands
 ******************************************************************************/
