@@ -4,10 +4,9 @@
 * DESCRIPTION: main program
 * COPYRIGHT  : (C) 1999  Joris van der Hoeven
 *******************************************************************************
-* This software falls under the GNU general public license and comes WITHOUT
-* ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for more details.
-* If you don't have this file, write to the Free Software Foundation, Inc.,
-* 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+* This software falls under the GNU general public license version 3 or later.
+* It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+* in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ******************************************************************************/
 
 #include "boot.hpp"
@@ -124,11 +123,11 @@ TeXmacs_main (int argc, char** argv) {
 	exit (0);
       }
       else if ((s == "-p") || (s == "-path")) {
-	system ("echo $TEXMACS_PATH");
+	cout << get_env ("TEXMACS_PATH") << "\n";
 	exit (0);
       }
       else if ((s == "-bp") || (s == "-binpath")) {
-	system ("echo $TEXMACS_BIN_PATH");
+	cout << get_env ("TEXMACS_BIN_PATH") << "\n";
 	exit (0);
       }
       else if ((s == "-q") || (s == "-quit"))
@@ -195,6 +194,7 @@ TeXmacs_main (int argc, char** argv) {
   server sv;
 
   for (i=1; i<argc; i++) {
+    if (argv[i] == NULL) break;
     string s= argv[i];
     if ((N(s)>=2) && (s(0,2)=="--")) s= s (1, N(s));
     if ((s[0] != '-') && (s[0] != '+')) {
