@@ -4,10 +4,9 @@
 * DESCRIPTION: text boxes
 * COPYRIGHT  : (C) 1999  Joris van der Hoeven
 *******************************************************************************
-* This software falls under the GNU general public license and comes WITHOUT
-* ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for more details.
-* If you don't have this file, write to the Free Software Foundation, Inc.,
-* 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+* This software falls under the GNU general public license version 3 or later.
+* It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+* in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ******************************************************************************/
 
 #include "boxes.hpp"
@@ -277,8 +276,8 @@ text_box_rep::get_leaf_offset (string search) {
 
 static string
 get_delimiter (string s, font fn, SI height) {
-  if ((N(s)<2) || (s[0]!='<') || (s[N(s)-1]!='>'))
-    fatal_error ("Invalid rubber character", "get_delimiter");
+  ASSERT (N(s) >= 2 && s[0] == '<' && s[N(s)-1] == '>',
+	  "invalid rubber character");
   height -= PIXEL;
   string radical= s (0, N(s)-1) * "-";
   string first  = radical * "0>";
@@ -311,8 +310,8 @@ get_delimiter (string s, font fn, SI height) {
 
 static string
 get_wide (string s, font fn, SI width) {
-  if ((N(s)<2) || (s[0]!='<') || (s[N(s)-1]!='>'))
-    fatal_error ("Invalid rubber character", "get_wide");
+  ASSERT (N(s) >= 2 && s[0] == '<' && s[N(s)-1] == '>',
+	  "invalid rubber character");
   string radical= s (0, N(s)-1) * "-";
   string first  = radical * "0>";
   metric ex;
@@ -353,8 +352,8 @@ delimiter_box (path ip, string s, font fn, color col, SI bot, SI top) {
 
 box
 big_operator_box (path ip, string s, font fn, color col, int n) {
-  if ((N(s)<2) || (s[0]!='<') || (s[N(s)-1]!='>'))
-    fatal_error ("Invalid rubber character", "big_operator_box");
+  ASSERT (N(s) >= 2 && s[0] == '<' && s[N(s)-1] == '>',
+	  "invalid rubber character");
   string r= s (0, N(s)-1) * "-" * as_string (n) * ">";
   metric ex;
   fn->get_extents (r, ex);
@@ -374,5 +373,5 @@ wide_box (path ip, string s, font fn, color col, SI width) {
 
 box
 text_box (path ip, int pos, string s, font fn, color col) {
-  return new text_box_rep (ip, pos, s, fn, col);
+  return tm_new<text_box_rep> (ip, pos, s, fn, col);
 }
