@@ -4,10 +4,9 @@
 * DESCRIPTION: Bridge between logical and physically typesetted document
 * COPYRIGHT  : (C) 1999  Joris van der Hoeven
 *******************************************************************************
-* This software falls under the GNU general public license and comes WITHOUT
-* ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for more details.
-* If you don't have this file, write to the Free Software Foundation, Inc.,
-* 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+* This software falls under the GNU general public license version 3 or later.
+* It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+* in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ******************************************************************************/
 
 #include "bridge.hpp"
@@ -59,7 +58,7 @@ bridge_document_rep::initialize_acc () {
 
 bridge
 bridge_document (typesetter ttt, tree st, path ip) {
-  return new bridge_document_rep (ttt, st, ip);
+  return tm_new<bridge_document_rep> (ttt, st, ip);
 }
 
 /******************************************************************************
@@ -69,8 +68,8 @@ bridge_document (typesetter ttt, tree st, path ip) {
 void
 bridge_document_rep::notify_assign (path p, tree u) {
   // cout << "Assign " << p << ", " << u << " in " << st << "\n";
-  if (is_nil (p) && (!is_func (u, DOCUMENT)) && (!is_func (u, PARA)))
-    fatal_error ("Nil path", "bridge_document_rep::notify_assign");
+  ASSERT (!is_nil (p) || is_func (u, DOCUMENT) || is_func (u, PARA),
+	  "nil path");
   if (is_nil (p)) { st= u; initialize (); }
   else {
     if (is_atom (p)) {
@@ -89,7 +88,7 @@ bridge_document_rep::notify_assign (path p, tree u) {
 void
 bridge_document_rep::notify_insert (path p, tree u) {
   // cout << "Insert " << p << ", " << u << " in " << st << "\n";
-  if (is_nil (p)) fatal_error ("Nil path", "bridge_document_rep::notify_insert");
+  ASSERT (!is_nil (p), "nil path");
   if (is_atom (p)) {
     int i, j, n= N(brs), pos= p->item, nr= N(u);
     array<bridge> brs2 (n+nr);
@@ -115,7 +114,7 @@ bridge_document_rep::notify_insert (path p, tree u) {
 void
 bridge_document_rep::notify_remove (path p, int nr) {
   // cout << "Remove " << p << ", " << nr << " in " << st << "\n";
-  if (is_nil (p)) fatal_error ("Nil path", "bridge_document_rep::notify_remove");
+  ASSERT (!is_nil (p), "nil path");
   if (is_atom (p)) {
     int i, n= N(brs), pos= p->item;
     array<bridge> brs2 (n-nr);
