@@ -5,10 +5,9 @@
 *              an array of line_items is created of the right types.
 * COPYRIGHT  : (C) 1999  Joris van der Hoeven
 *******************************************************************************
-* This software falls under the GNU general public license and comes WITHOUT
-* ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for more details.
-* If you don't have this file, write to the Free Software Foundation, Inc.,
-* 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+* This software falls under the GNU general public license version 3 or later.
+* It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+* in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ******************************************************************************/
 
 #include "concater.hpp"
@@ -145,6 +144,7 @@ concater_rep::with_limits (int status) {
 
 void
 concater_rep::typeset (tree t, path ip) {
+  // cout << "Typeset " << t << "\n";
   // cout << "Typeset " << t << ", " << ip << ", " << obtain_ip (t) << "\n";
 
   /*
@@ -706,26 +706,26 @@ concater_rep::concater_rep (edit_env env2): env (env2) {}
 
 array<line_item>
 typeset_concat (edit_env env, tree t, path ip) {
-  concater ccc= new concater_rep (env);
+  concater ccc= tm_new<concater_rep> (env);
   ccc->typeset (t, ip);
   ccc->finish ();
   array<line_item> a= ccc->a;
-  delete ccc;
+  tm_delete (ccc);
   return a;
 }
 
 array<line_item>
 typeset_marker (edit_env env, path ip) {
-  concater ccc= new concater_rep (env);
+  concater ccc= tm_new<concater_rep> (env);
   ccc->marker (ip);
   array<line_item> a= ccc->a;
-  delete ccc;
+  tm_delete (ccc);
   return a;
 }
 
 box
 typeset_as_concat (edit_env env, tree t, path ip) {
-  concater ccc= new concater_rep (env);
+  concater ccc= tm_new<concater_rep> (env);
   ccc->typeset (t, ip);
   ccc->finish ();
   array<line_item> a= ccc->a;
@@ -744,7 +744,7 @@ typeset_as_concat (edit_env env, tree t, path ip) {
   }
   box b= concat_box (ip, items, spc);
 
-  delete ccc;
+  tm_delete (ccc);
   return b;
 }
 
