@@ -4,10 +4,9 @@
 * DESCRIPTION: evaluation of trees w.r.t. the environment
 * COPYRIGHT  : (C) 1999  Joris van der Hoeven
 *******************************************************************************
-* This software falls under the GNU general public license and comes WITHOUT
-* ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for more details.
-* If you don't have this file, write to the Free Software Foundation, Inc.,
-* 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+* This software falls under the GNU general public license version 3 or later.
+* It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+* in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ******************************************************************************/
 
 #include "env.hpp"
@@ -1095,7 +1094,8 @@ edit_env_rep::exec_merge (tree t) {
   if (is_concat (acc)) acc= var_as_string (acc);
   for (i=1; i<n; i++) {
     tree add= exec (t[i]);
-    if (is_atomic (acc) && (is_atomic (add) || is_concat (add)))
+    if (is_atomic (acc) &&
+	(is_atomic (add) || is_concat (add) || is_document (add)))
       acc= acc->label * var_as_string (add);
     else if (is_tuple (acc) && is_tuple (add))
       acc= acc * add;
@@ -1114,7 +1114,11 @@ edit_env_rep::exec_merge (tree t) {
 	r[N(r)-1]= u;
 	acc= r;
       }
-    else return tree (ERROR, "bad merge");
+    else {
+      //cout << "acc= " << acc << "\n";
+      //cout << "add= " << add << "\n";
+      return tree (ERROR, "bad merge");
+    }
   }
   return acc;
 }
@@ -1395,23 +1399,35 @@ edit_env_rep::exec_set_binding (tree t) {
   tree keys, value;
   if (N(t) == 1) {
     keys= read ("the-tags");
-    if (!is_tuple (keys))
+    if (!is_tuple (keys)) {
+      //cout << "t= " << t << "\n";
+      //cout << "keys= " << keys << "\n";
       return tree (ERROR, "bad set binding");
+    }
     for (int i=0; i<N(keys); i++)
-      if (!is_atomic (keys[i]))
+      if (!is_atomic (keys[i])) {
+	//cout << "t= " << t << "\n";
+	//cout << "keys= " << keys << "\n";
 	return tree (ERROR, "bad set binding");
+      }
     value= exec (t[0]);
     assign (string ("the-tags"), tree (TUPLE));
     assign (string ("the-label"), copy (value));
   }
   else if (N(t) >= 2) {
     tree key= exec (t[0]);
-    if (!is_atomic (key)) 
+    if (!is_atomic (key)) {
+      //cout << "t= " << t << "\n";
+      //cout << "key= " << key << "\n";
       return tree (ERROR, "bad set binding");
+    }
     keys= tuple (key);
     value= exec (t[1]);
   }
-  else return tree (ERROR, "bad set binding");
+  else {
+    //cout << "t= " << t << "\n";
+    return tree (ERROR, "bad set binding");
+  }
 
   for (int i=0; i<N(keys); i++) {
     string key= keys[i]->label;
@@ -1437,7 +1453,7 @@ edit_env_rep::exec_set_binding (tree t) {
       }
     }
   }
-  return keys;
+  return tree (HIDDEN, "", keys);
 }
 
 tree
