@@ -5,10 +5,9 @@
 *              hyphenation and creation of page items
 * COPYRIGHT  : (C) 1999  Joris van der Hoeven
 *******************************************************************************
-* This software falls under the GNU general public license and comes WITHOUT
-* ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for more details.
-* If you don't have this file, write to the Free Software Foundation, Inc.,
-* 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+* This software falls under the GNU general public license version 3 or later.
+* It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+* in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ******************************************************************************/
 
 #include "Line/lazy_paragraph.hpp"
@@ -29,7 +28,7 @@ line_breaks (array<line_item> a, int start, int end,
 
 lazy_paragraph_rep::lazy_paragraph_rep (edit_env env2, path ip):
   lazy_rep (LAZY_PARAGRAPH, ip),
-  env (env2), style (""), sss (new stacker_rep)
+  env (env2), style (""), sss (tm_new<stacker_rep> ())
 {
   sss->ip= ip; // is this necessary?
   style (PAR_FIRST)   = env->read (PAR_FIRST);
@@ -60,7 +59,7 @@ lazy_paragraph_rep::lazy_paragraph_rep (edit_env env2, path ip):
 }
 
 lazy_paragraph_rep::~lazy_paragraph_rep () {
-  delete sss;
+  tm_delete (sss);
 }
 
 lazy_paragraph_rep::operator tree () {
